@@ -23,7 +23,7 @@
 #include "ADM_pp.h"
 #include "ADM_colorspace.h"
 #include "ADM_vidMisc.h"
-#include "ADM_audiocodec/ADM_audiocodec.h"
+#include "ADM_audiocodec.h"
 #include "ADM_codec.h"
 #include "DIA_coreToolkit.h"
 #include "ADM_vidMisc.h"
@@ -69,7 +69,7 @@ bool        ADM_EditorSegment::updateRefVideo(void)
         demuxer->getPtsDts(0,&pts,&dts);
         if(pts!=ADM_NO_PTS && pts >0)
         {
-            ADM_warning("Updating firstFramePTS, The first frame has a PTS >0, adjusting to %"PRIu64" ms\n",pts/1000);
+            ADM_warning("Updating firstFramePTS, The first frame has a PTS >0, adjusting to %" PRIu64" ms\n",pts/1000);
             ref->firstFramePts=pts;
         }else
         {
@@ -83,7 +83,7 @@ bool        ADM_EditorSegment::updateRefVideo(void)
     {
     _SEGMENT *seg=getSegment(n-1);
     uint64_t dur=ref->_aviheader->getVideoDuration();
-    printf("Current duration %"PRIu64" ms real one %"PRIu64" ms\n",dur/1000,seg->_durationUs/1000);
+    printf("Current duration %" PRIu64" ms real one %" PRIu64" ms\n",dur/1000,seg->_durationUs/1000);
     }
 
     return true;
@@ -114,7 +114,7 @@ bool        ADM_EditorSegment::addReferenceVideo(_VIDEOS *ref)
   // Probe the real time increment as the value determined from FPS may be incorrect due to interlace
   uint64_t firstNonZeroDts=ADM_NO_PTS,pts,dts;
   int firstNonZeroDtsFrame;
-  ADM_info("[editor] Original frame increment %s\n",ADM_us2plain(ref->timeIncrementInUs));
+  ADM_info("[editor] Original frame increment %s %d\n",ADM_us2plain(ref->timeIncrementInUs),(int)ref->timeIncrementInUs);
   uint64_t minDelta=100000;
   uint64_t maxDelta=0;
   for (int frame=0; frame<info.nb_frames; frame++)
@@ -135,14 +135,14 @@ bool        ADM_EditorSegment::addReferenceVideo(_VIDEOS *ref)
           firstNonZeroDtsFrame=frame;
       }
   }
-  ADM_info("[Editor] min increment %s\n",ADM_us2plain(minDelta));
-  ADM_info("[Editor] max increment %s\n",ADM_us2plain(maxDelta));
+  ADM_info("[Editor] min increment %s - %d\n",ADM_us2plain(minDelta),(int)minDelta);
+  ADM_info("[Editor] max increment %s - %d\n",ADM_us2plain(maxDelta),(int)maxDelta);
   
   //if (minDelta==ref->timeIncrementInUs*2)
               //ref->timeIncrementInUs=minDelta;
 
   
-  ADM_info("[Editor] About %"PRIu64" microseconds per frame\n",ref->timeIncrementInUs);
+  ADM_info("[Editor] About %" PRIu64" microseconds per frame\n",ref->timeIncrementInUs);
   ref->_nb_video_frames = info.nb_frames;
   //
   //  And automatically create the segment
@@ -166,12 +166,10 @@ bool        ADM_EditorSegment::addReferenceVideo(_VIDEOS *ref)
         if(pts==ADM_NO_PTS) ADM_warning("First frame has unknown PTS\n");
         if(pts!=ADM_NO_PTS &&pts)
         {
-            ADM_warning("The first frame has a PTS >0, adjusting to %"PRIu64" ms\n",pts/1000);
+            ADM_warning("The first frame has a PTS >0, adjusting to %" PRIu64" ms\n",pts/1000);
             ref->firstFramePts=pts;
         }
 
-    if(!segments.empty()) undoSegments.push_back(segments);
-
     segments.push_back(seg);
     videos.push_back(*ref);
     updateStartTime();
@@ -185,17 +183,15 @@ bool        ADM_EditorSegment::deleteSegments()
 {
     ADM_info("Clearing a new segment\n");
     segments.clear();
-    undoSegments.clear();
     return true;
 }
 /**
-    \fn deleteSegments
-    \brief Empty the segments list
+    \fn addSegment
+    \brief Add a segment to the segments list
 */
 bool        ADM_EditorSegment::addSegment(_SEGMENT *seg)
 {
     ADM_info("Adding a new segment\n");
-    undoSegments.push_back(segments);
     segments.push_back(*seg);
     updateStartTime();
     return true;
@@ -250,24 +246,9 @@ bool ADM_EditorSegment::deleteAll (void)
 
     }
 
+    clipboard.clear();
     videos.clear();
     segments.clear();
-    undoSegments.clear();
-    return true;
-}
-
-
-/**
-    \fn undo
-    \brief
-*/
-bool        ADM_EditorSegment::undo(void)
-{
-    if(undoSegments.empty()) return false;
-    clipboard.clear();
-    segments=undoSegments.back(); 
-    undoSegments.pop_back();
-    updateStartTime();
     return true;
 }
 /**
@@ -279,7 +260,6 @@ bool        ADM_EditorSegment::resetSegment(void)
     //
     aviInfo info;
     segments.clear();
-    undoSegments.clear();
     int n=videos.size();
     for(int i=0;i<n;i++)
     {
@@ -322,6 +302,29 @@ _VIDEOS     *ADM_EditorSegment::getRefVideo(int i)
     }
     return &(videos[i]);
 }
+/**
+    \fn getSegments
+    \brief getter for the list of segments
+*/
+ListOfSegments ADM_EditorSegment::getSegments(void)
+{
+    if(segments.empty()) ADM_assert(0);
+    ListOfSegments segm=segments;
+    return segm;
+}
+/**
+    \fn setSegments
+    \brief setter for the list of segments
+*/
+bool ADM_EditorSegment::setSegments(ListOfSegments segm)
+{
+    if(segm.size())
+    {
+        segments=segm;
+        return true;
+    }
+    return false;
+}
 /**
     \fn getNbRefVideo
     \brief getNbRefVideo
@@ -348,7 +351,6 @@ bool         ADM_EditorSegment::updateStartTime(void)
     if(!n) return true;
     
     uint64_t t=0;
-    t=segments[0]._startTimeUs;
     for(int i=0;i<n;i++)
     {
         segments[i]._startTimeUs=t;
@@ -419,7 +421,7 @@ bool        ADM_EditorSegment::getRefFromTime(uint64_t xtime,uint32_t *refVideo)
     uint64_t segTime;
     if(false== convertLinearTimeToSeg(  xtime, &seg, &segTime))
     {
-        ADM_warning("Cannot identify segment for time %"PRIu64" ms\n",xtime/1000);
+        ADM_warning("Cannot identify segment for time %" PRIu64" ms\n",xtime/1000);
         return false;
     }
     _SEGMENT *s=getSegment(seg);
@@ -475,7 +477,7 @@ bool        ADM_EditorSegment::convertLinearTimeToSeg(  uint64_t frameTime, uint
             return true;
         }
     }
-    ADM_warning("Cannot find segment matching time %"PRIu64"ms \n",frameTime/1000);
+    ADM_warning("Cannot find segment matching time %" PRIu64"ms \n",frameTime/1000);
     dump();
     return false;
 }
@@ -510,7 +512,7 @@ static bool TimeToFrame(_VIDEOS *v,uint64_t time,uint32_t *frame,uint32_t *oflag
             {
                 if(dts>time)
                 {
-                    ADM_error("We reached frame %d with a PTS of %"PRIu64" when looking for PTS %"PRIu64"\n",
+                    ADM_error("We reached frame %d with a PTS of %" PRIu64" when looking for PTS %" PRIu64"\n",
                                             i,dts,time);
                     warn=true;
                 }
@@ -530,7 +532,7 @@ uint32_t    ADM_EditorSegment::intraTimeToFrame(uint32_t refVideo,uint64_t seekT
         ADM_assert(v);
         if(false==TimeToFrame(v,seekTime,&frame,&flags))
         {
-            ADM_error("Cannot find frame with time %"PRIu64"ms\n",seekTime/1000);
+            ADM_error("Cannot find frame with time %" PRIu64"ms\n",seekTime/1000);
             ADM_assert(0);
         }
         uint32_t next;
@@ -565,21 +567,21 @@ bool        ADM_EditorSegment::removeChunk(uint64_t from, uint64_t to)
     uint32_t startSeg,endSeg;
     uint64_t startOffset,endOffset;
 
-    ADM_info("Cutting from %"PRIu64" to %"PRIu64" ms\n",from/1000,to/1000);
+    ADM_info("Cutting from %" PRIu64" to %" PRIu64" ms\n",from/1000,to/1000);
     dump();
     if(false==convertLinearTimeToSeg( from,&startSeg,&startOffset))
     {
-        ADM_warning("Cannot get starting point (%"PRIu64" ms\n",from/1000);
+        ADM_warning("Cannot get starting point (%" PRIu64" ms\n",from/1000);
         return false;
     }
     if(false==convertLinearTimeToSeg( to,&endSeg,&endOffset))
     {
-        ADM_warning("Cannot get starting point (%"PRIu64" ms\n",from/1000);
+        ADM_warning("Cannot get end point (%" PRIu64" ms\n",to/1000);
         return false;
     }
 
-    ADM_info("Start, seg %"PRIu32" Offset :%"PRIu64" ms\n",startSeg,startOffset);
-    ADM_info("End  , seg %"PRIu32" Offset :%"PRIu64" ms\n",endSeg,endOffset);
+    ADM_info("Start, seg %" PRIu32" Offset :%" PRIu64" ms\n",startSeg,startOffset);
+    ADM_info("End  , seg %" PRIu32" Offset :%" PRIu64" ms\n",endSeg,endOffset);
     ListOfSegments tmp=segments;
     
 
@@ -615,12 +617,50 @@ bool        ADM_EditorSegment::removeChunk(uint64_t from, uint64_t to)
         return false;
 
     }
-    undoSegments.push_back(tmp);
     dump();
     return true;
 }
+/**
+    \fn truncateVideo
+    \brief Remove a part of the video from the given time to the end
+*/
+bool ADM_EditorSegment::truncateVideo(uint64_t from)
+{
+    uint32_t startSeg;
+    uint64_t startOffset;
 
+    ADM_info("Truncating from %" PRIu64" ms\n",from/1000);
+    dump();
+    if(false==convertLinearTimeToSeg(from,&startSeg,&startOffset))
+    {
+        ADM_warning("Cannot get starting point for linear time %" PRIu64" ms\n",from/1000);
+        return false;
+    }
 
+    ADM_info("Start in segment %" PRIu32" at offset :%" PRIu64" ms\n",startSeg,startOffset);
+    ListOfSegments tmp=segments;
+
+    _SEGMENT *first=getSegment(startSeg);
+    // shorten the start segment
+    first->_durationUs=startOffset;
+    // remove following segments
+    int n=segments.size();
+    for(int i=startSeg+1;i<n;i++)
+    {
+        segments.erase(segments.begin()+startSeg+1);
+    }
+    updateStartTime();
+    removeEmptySegments();
+    if(isEmpty())
+    {
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("adm","Error"),QT_TRANSLATE_NOOP("adm","You cannot remove *all* the video\n"));
+        segments=tmp;
+        updateStartTime();
+        return false;
+    }
+    dump();
+    return true;
+}
 /**
     \fn dump
     \brief Dump the segment content
@@ -638,11 +678,11 @@ void ADM_EditorSegment::dumpSegmentsInternal(ListOfSegments &l)
         _SEGMENT s=l.at(i);
 
         printf("Segment :%d/%d\n",i,n);
-        printf("\tReference    :%"PRIu32"    %s\n",s._reference,ADM_us2plain(s._reference));
-        printf("\tstartLinear  :%08"PRIu64" %s\n",s._startTimeUs,ADM_us2plain(s._startTimeUs));
-        printf("\tduration     :%08"PRIu64" %s\n",s._durationUs,ADM_us2plain(s._durationUs));
-        printf("\trefStartPts  :%08"PRIu64" %s\n",s._refStartTimeUs,ADM_us2plain(s._refStartTimeUs));
-        printf("\trefStartDts  :%08"PRIu64" %s\n",s._refStartDts,ADM_us2plain(s._refStartDts));
+        printf("\tReference    :%" PRIu32"    %s\n",s._reference,ADM_us2plain(s._reference));
+        printf("\tstartLinear  :%08" PRIu64" %s\n",s._startTimeUs,ADM_us2plain(s._startTimeUs));
+        printf("\tduration     :%08" PRIu64" %s\n",s._durationUs,ADM_us2plain(s._durationUs));
+        printf("\trefStartPts  :%08" PRIu64" %s\n",s._refStartTimeUs,ADM_us2plain(s._refStartTimeUs));
+        printf("\trefStartDts  :%08" PRIu64" %s\n",s._refStartDts,ADM_us2plain(s._refStartDts));
     }
 }
 
@@ -657,11 +697,11 @@ void       ADM_EditorSegment::dumpSegment(int i)
         _SEGMENT *s=getSegment(i);
 
         printf("Segment :%d/%d\n",i,n);
-        printf("\tReference    :%"PRIu32"    %s\n",s->_reference,ADM_us2plain(s->_reference));
-        printf("\tstartLinear  :%08"PRIu64" %s\n",s->_startTimeUs,ADM_us2plain(s->_startTimeUs));
-        printf("\tduration     :%08"PRIu64" %s\n",s->_durationUs,ADM_us2plain(s->_durationUs));
-        printf("\trefStartPts  :%08"PRIu64" %s\n",s->_refStartTimeUs,ADM_us2plain(s->_refStartTimeUs));
-        printf("\trefStartDts  :%08"PRIu64" %s\n",s->_refStartDts,ADM_us2plain(s->_refStartDts));
+        printf("\tReference    :%" PRIu32"    %s\n",s->_reference,ADM_us2plain(s->_reference));
+        printf("\tstartLinear  :%08" PRIu64" %s\n",s->_startTimeUs,ADM_us2plain(s->_startTimeUs));
+        printf("\tduration     :%08" PRIu64" %s\n",s->_durationUs,ADM_us2plain(s->_durationUs));
+        printf("\trefStartPts  :%08" PRIu64" %s\n",s->_refStartTimeUs,ADM_us2plain(s->_refStartTimeUs));
+        printf("\trefStartDts  :%08" PRIu64" %s\n",s->_refStartDts,ADM_us2plain(s->_refStartDts));
 }
 /**
     \fn dumpRefVideos
@@ -677,9 +717,9 @@ void ADM_EditorSegment::dumpRefVideos(void)
         _VIDEOS *s=getRefVideo(i);
 
         printf("Videos :%d/%d\n",i,n);
-        printf("\tfirstFramePts      :%08"PRIu64" %s\n",s->firstFramePts,ADM_us2plain(s->firstFramePts));
-        printf("\ttimeIncrementInUs  :%08"PRIu64" %s\n",s->timeIncrementInUs,ADM_us2plain(s->timeIncrementInUs));
-        printf("\tnb frames    :%04"PRIu32"\n",s->_nb_video_frames);
+        printf("\tfirstFramePts      :%08" PRIu64" %s\n",s->firstFramePts,ADM_us2plain(s->firstFramePts));
+        printf("\ttimeIncrementInUs  :%08" PRIu64" %s\n",s->timeIncrementInUs,ADM_us2plain(s->timeIncrementInUs));
+        printf("\tnb frames    :%04" PRIu32"\n",s->_nb_video_frames);
     }
 
 }
@@ -697,7 +737,7 @@ void ADM_EditorSegment::dumpRefVideos(void)
     vidHeader *demuxer=vid->_aviheader;
     if(false==TimeToFrame(vid,pts,&frame,&flags))
     {
-            ADM_warning("Cannot get frame with pts=%"PRIu64" ms\n",pts/1000);
+            ADM_warning("Cannot get frame with pts=%" PRIu64" ms\n",pts/1000);
             return false;
     }
     // Now get DTS..
@@ -726,7 +766,7 @@ void ADM_EditorSegment::dumpRefVideos(void)
     }
     if(deltaFrame<0)
     {
-        ADM_warning("Cannot find a valid DTS for pts=%"PRIu64"ms\n",pts/1000);
+        ADM_warning("Cannot find a valid DTS for pts=%" PRIu64"ms\n",pts/1000);
         *dts=pts;
         return false;
     }
@@ -777,12 +817,12 @@ bool        ADM_EditorSegment::LinearToRefTime(int segNo,uint64_t linear,uint64_
     ADM_assert(seg);
     if(linear<seg->_startTimeUs)
     {
-        ADM_warning("This given time is not in the segment: Given time %"PRIu64", seg start at %"PRIu64"\n",
+        ADM_warning("This given time is not in the segment: Given time %" PRIu64", seg start at %" PRIu64"\n",
                         linear, seg->_startTimeUs);
     }
     if(linear>=seg->_startTimeUs+seg->_durationUs)
     {
-        ADM_warning("This given time is not in the segment: Given time %"PRIu64", seg end at %"PRIu64"\n",
+        ADM_warning("This given time is not in the segment: Given time %" PRIu64", seg end at %" PRIu64"\n",
                         linear, seg->_startTimeUs+seg->_durationUs);
 
     }
@@ -811,7 +851,7 @@ bool        ADM_EditorSegment::copyToClipBoard(uint64_t startTime, uint64_t endT
     clipboard.clear();
     for(int seg=startSeg;seg<=endSeg;seg++)
     {
-        _SEGMENT s=segments[seg];
+        _SEGMENT s=segments[seg],s2=s;
         aprintf("Adding segment %d to clipboard\n",seg);
         if(s._startTimeUs<=startTime && (s._startTimeUs+s._durationUs)>startTime)
         {
@@ -820,15 +860,15 @@ bool        ADM_EditorSegment::copyToClipBoard(uint64_t startTime, uint64_t endT
             uint64_t offset=startTime-s._startTimeUs;
             s._refStartTimeUs+=offset;
             s._durationUs-=offset;         // take into account the part we chopped
-            aprintf("Marker A is here offset=%d\n",(int)offset);
+            s._startTimeUs+=offset;
+            aprintf("Marker A is here offset=%" PRIu64"\n",offset);
         }
-        if(s._startTimeUs<=endTime && (s._startTimeUs+s._durationUs)>endTime)
-        {
-            
+        if(s2._startTimeUs<=endTime && (s2._startTimeUs+s2._durationUs)>=endTime)
+        {            
             // need to refine last seg            
-            uint64_t offset=endTime-s._startTimeUs;
-            s._durationUs=offset;
-            aprintf("Marker B is here offset=%d\n",(int)offset);
+            uint64_t offset=endTime-s2._startTimeUs;
+            s._durationUs=endTime-s._startTimeUs;
+            aprintf("Marker B is here offset=%" PRIu64"\n",offset);
         }
         // TODO refine timing for 1st/last/duration/...
         clipboard.push_back(s);        
@@ -854,10 +894,16 @@ bool        ADM_EditorSegment::dumpClipBoard()
  */
 bool        ADM_EditorSegment::pasteFromClipBoard(uint64_t currentTime)
 {
+    if(clipboardEmpty())
+    {
+        ADM_info("The clipboard is empty, nothing to do\n");
+        return true;
+    }
     ADM_info("Pasting from clipboard to %s\n",ADM_us2plain(currentTime));
     uint32_t startSeg;
     uint64_t startSegTime;
     convertLinearTimeToSeg(  currentTime, &startSeg,&startSegTime);    
+    ListOfSegments tmp=segments;
     ListOfSegments newSegs;
     int n=segments.size();
     for(int i=0;i<n;i++)
@@ -889,7 +935,36 @@ bool        ADM_EditorSegment::pasteFromClipBoard(uint64_t currentTime)
     }
     segments=newSegs;
     updateStartTime();
+    dump();
     return true;
 }
 
+/**
+ * \fn appendFromClipBoard
+ * \brief append clipboard at the end of video
+ * @return 
+ */
+bool ADM_EditorSegment::appendFromClipBoard(void)
+{
+    if(clipboardEmpty())
+    {
+        ADM_info("The clipboard is empty, nothing to do\n");
+        return true;
+    }
+    ADM_info("Appending from clipboard\n");
+    ListOfSegments tmp=segments;
+    for(int i=0;i<clipboard.size();i++) segments.push_back(clipboard[i]);
+    updateStartTime();
+    dump();
+    return true;
+}
+
+/**
+ * \fn clipboardEmpty
+ */
+bool ADM_EditorSegment::clipboardEmpty(void)
+{
+    return clipboard.empty();
+}
+
 //EOF
