@@ -23,6 +23,7 @@ extern "C" {
 #include "libavcodec/avcodec.h"
 #include "libavutil/pixfmt.h"
 #include "libavutil/pixdesc.h"
+#include "libavutil/hwcontext_dxva2.h"
 #define CONFIG_DXVA2 1
 #include "libavcodec/dxva2_internal.h"
 #include "libavcodec/dxva2.h"
@@ -60,7 +61,6 @@ bool dxva2Usable(void)
     if(!prefs->get(FEATURES_DXVA2,&v)) v=false;
     return v;
 }
-
 /**
     \fn dxva2Probe
     \brief Try loading d3d and dxva2...
@@ -224,9 +224,21 @@ static enum AVPixelFormat ADM_DXVA2_getFormat(struct AVCodecContext *avctx,  con
         switch(avctx->codec_id)  //AV_CODEC_ID_H265
         {
             FMT_V_CHECK(H264,H264)
-            FMT_V_CHECK(H265,H265)
-//            FMT_V_CHECK(VC1,VC1)
-//            FMT_V_CHECK(VP9,VP9)
+            case AV_CODEC_ID_H265:
+              {
+                    admD3D::ADM_vendorID vid=admD3D::getVendorID();
+                    if(vid==admD3D::VENDOR_INTEL)
+                    {
+                        ADM_warning("Intel blacklisted for H265 decoding \n");
+                    }
+                    else
+                    {
+                      outPix=AV_PIX_FMT_DXVA2_VLD;
+                      id=avctx->codec_id;
+                    }
+              }
+              break;
+            //FMT_V_CHECK(H265,H265)
             default:
                 ADM_info("DXVA2 No hw support for format %d\n",avctx->codec_id);
                 continue;
@@ -249,6 +261,18 @@ static enum AVPixelFormat ADM_DXVA2_getFormat(struct AVCodecContext *avctx,  con
     return AV_PIX_FMT_NONE;
 }
 }
+/**
+ * \fn cleanupSurfaces
+ */
+static void cleanupSurfaces( std::vector<admDx2Surface *>&surfaces)
+{
+    int n=surfaces.size();
+    for(int i=0;i<n;i++)
+    {
+        delete surfaces[i];
+    }
+    surfaces.clear();
+}
 
 /**
  *
@@ -305,30 +329,33 @@ decoderFFDXVA2::decoderFFDXVA2(AVCodecContext *avctx,decoderFF *parent)
 
     // Allocate surfaces..
     int bits=dxvaBitDepthFromContext(avctx);
-    if(!admDxva2::allocateD3D9Surface(num_surfaces,avctx->coded_width,avctx->coded_height,surfaces,align,bits))
-    {
-        ADM_warning("Cannot allocate surfaces \n");
-        return ;
-    }
+    std::vector<admDx2Surface *>dmSurfaces;
+    bool er=false;
+    if(!admDxva2::allocateDecoderSurface(this,avctx->coded_width,avctx->coded_height,align,num_surfaces,surfaces,dmSurfaces, bits))
+        {
+                ADM_warning("Cannot allocate surfaces\n");
+                return ;
+        }
     dx_context->decoder=admDxva2::createDecoder(avctx->codec_id,avctx->coded_width, avctx->coded_height,num_surfaces,surfaces,align,bits);
     aprintf("Decoder=%p\n",dx_context->decoder);
     if(!dx_context->decoder)
     {
         ADM_warning("Cannot create decoder\n");
+        cleanupSurfaces(dmSurfaces);
         return ;
     }
     ADM_info("DXVA2 decoder created\n");
     // Populare queue with them
     for (int i=0;i<num_surfaces;i++)
     {
-        admDx2Surface *w=new admDx2Surface(this,align);
-        w->surface=surfaces[i];
+        admDx2Surface *w=dmSurfaces[i];
         w->decoder = dx_context->decoder;
         dxvaPool.freeSurfaceQueue.append(w);
         dxvaPool.allSurfaceQueue.append(w);
         aprintf("Appending surface %p->internal %p\n",w,w->surface);
     }
     //
+    dmSurfaces.clear();
     _context->hwaccel_context = dx_context;
     _context->get_buffer2     = ADM_DXVA2getBuffer;
     _context->draw_horiz_band = NULL;
