@@ -38,6 +38,7 @@
 #include "ADM_preview.h"
 #include "ADM_coreVideoEncoder.h"
 #include "ADM_videoEncoderApi.h"
+#include "ADM_muxerProto.h"
 #include "ADM_audioFilter/include/ADM_audioFilterInterface.h"
 
 #include "avi_vars.h"
@@ -47,10 +48,10 @@
 
 #include "ADM_edAudioTrackExternal.h"
 #include "ADM_threads.h"
-
+#include "ADM_muxerProto.h"
 admMutex singleThread;
 
-renderZoom currentZoom=ZOOM_1_1;
+float currentZoom=ZOOM_1_1;
 #include "DIA_audioTracks.h"
 //***********************************
 //******** A Function ***************
@@ -89,7 +90,7 @@ void        updateLoaded (bool resetMarker=true);
 extern void GUI_OpenApplicationLog();
 extern void GUI_OpenApplicationDataFolder();
 
-extern bool ADM_mux_configure(int index);
+//extern bool ADM_mux_configure(int index);
 void brokenAct(void);
 //
 //  Sub gui files...
@@ -171,33 +172,20 @@ void HandleAction (Action action)
         int actionId = (action - ACT_SCRIPT_ENGINE_FIRST) % 3;
 
         tempEngine = getScriptEngines()[engineIndex];
-#ifndef _WIN64
         std::string ext=tempEngine->defaultFileExtension();
-#endif
+
         switch (actionId)
         {
             case 0:
-#ifdef _WIN64
-                GUI_FileSelRead(QT_TRANSLATE_NOOP("adm","Select script to run"), RunScript);
-#else
                 GUI_FileSelReadExtension(QT_TRANSLATE_NOOP("adm","Select script to run"), ext.c_str(), RunScript);
-#endif
                 break;
 
             case 1:
-#ifdef _WIN64
-                GUI_FileSelRead(QT_TRANSLATE_NOOP("adm","Select script to debug"), DebugScript);
-#else
                 GUI_FileSelReadExtension(QT_TRANSLATE_NOOP("adm","Select script to debug"), ext.c_str(), DebugScript);
-#endif
                 break;
 
             case 2:
-#ifdef _WIN64
-                GUI_FileSelWrite(QT_TRANSLATE_NOOP("adm","Select script to save"), SaveScript);
-#else
                 GUI_FileSelWriteExtension(QT_TRANSLATE_NOOP("adm","Select script to save"), ext.c_str(), SaveScript);
-#endif
                 UI_refreshCustomMenu();
                 break;
         }
@@ -262,15 +250,28 @@ void HandleAction (Action action)
                             A_Resync();
                             return;
             }
+        case ACT_CLEAR_RECENT:
+            {
+                if(GUI_Question(QT_TRANSLATE_NOOP("adm","You are about to clear the list of recent files and projects. This can't be undone. Proceed?")))
+                {
+                    prefs->clear_lastfiles();
+                    prefs->clear_lastprojects();
+                    prefs->save();
+                    UI_updateRecentProjectMenu();
+                    UI_updateRecentMenu(); // the order matters here
+                }
+            }
+            return;
     case ACT_VIDEO_CODEC_CONFIGURE:
             videoEncoder6Configure();
             return;
     case ACT_ContainerConfigure:
-            {
+        {
+            if(!ADM_mx_getNbMuxers()) return;
             int index=UI_GetCurrentFormat();
             ADM_mux_configure(index);
             return;
-            }
+        }
     case ACT_VIDEO_CODEC_CHANGED:
         {
             int nw=UI_getCurrentVCodec();
@@ -415,8 +416,11 @@ void HandleAction (Action action)
         case ACT_ZOOM_1_1:
         case ACT_ZOOM_2_1:
         case ACT_ZOOM_4_1:
-                currentZoom=(renderZoom)((action-ACT_ZOOM_1_4)+ZOOM_1_4);
+                currentZoom=(float)(2<<(action-ACT_ZOOM_1_4))/8;
+                UI_setBlockZoomChangesFlag(true);
                 changePreviewZoom(currentZoom);
+                UI_setBlockZoomChangesFlag(false);
+                UI_resetZoomThreshold();
                 admPreview::samePicture();
                 break;
         case ACT_AUDIO_SELECT_TRACK:
@@ -542,12 +546,12 @@ void HandleAction (Action action)
               }
               video_body->getVideoInfo (avifileinfo);
               d=video_body->getVideoDuration()-d;
-              if(markA>=currentPts)
+              if(markA>currentPts)
               {
                   markA+=d;
                   markB+=d;
               }
-              if(markA<currentPts && currentPts<markB)
+              if(markA<=currentPts && currentPts<=markB)
               {
                   markB+=d;
               }
@@ -864,7 +868,7 @@ void  updateLoaded (bool resetMarker)
     }
 
   // Init renderer
-    admPreview::setMainDimension(avifileinfo->width, avifileinfo->height,ZOOM_AUTO);
+    admPreview::setMainDimension(avifileinfo->width, avifileinfo->height, ZOOM_AUTO);
   // Draw first frame
     GUI_setAllFrameAndTime();
     if(resetMarker)
@@ -987,6 +991,7 @@ void cleanUp (void)
  * @param mode
  * @return 
  */
+#define DEFAULT_SETTINGS_FILE ADM_getBaseDir()+std::string("defaultSettings.py")
 bool parseScript(IScriptEngine *engine, const char *name, IScriptEngine::RunMode mode)
 {
     bool ret;
@@ -1004,12 +1009,14 @@ bool parseScript(IScriptEngine *engine, const char *name, IScriptEngine::RunMode
         video_body->setProjectName(longname);
     }
 
-    prefs->set_lastprojectfile(longname);
+    if (std::string(longname) != DEFAULT_SETTINGS_FILE)
+    {
+        prefs->set_lastprojectfile(longname);
+        UI_updateRecentProjectMenu();
+    }
     delete [] longname;
     longname=NULL;
-    
-    
-    UI_updateRecentProjectMenu();
+
     // update main menu shift
     EditableAudioTrack *ed=video_body->getDefaultEditableAudioTrack();
     if(ed)
@@ -1066,7 +1073,7 @@ void A_saveScript(IScriptEngine* engine, const char* name)
  * @param engine
  * @param name
  */
-#define DEFAULT_SETTINGS_FILE ADM_getBaseDir()+std::string("defaultSettings.py")
+
 void A_saveDefaultSettings()
 {
     IScriptEngine *engine=getPythonScriptEngine();
@@ -1101,12 +1108,12 @@ bool A_loadDefaultSettings(void)
 {
   
     std::string defaultSettings=DEFAULT_SETTINGS_FILE;
-    if(ADM_fileExist(defaultSettings.c_str()))
-    {        
-        if(ADM_fileSize(defaultSettings.c_str())>5)
-        {
-                return A_runPythonScript( defaultSettings);
-        }
+    if(ADM_fileExist(defaultSettings.c_str()) && ADM_fileSize(defaultSettings.c_str())>5)
+    {
+        return A_runPythonScript( defaultSettings);
+    }else
+    { // default to MKV as output container instead of AVI if no user defined default settings exist
+        return video_body->setContainer("MKV",NULL);
     }
     return false;
 }
@@ -1478,7 +1485,7 @@ uint8_t GUI_close(void)
   if (avifileinfo)        // already opened ?
     {                // delete everything
       // if preview is on
-      admPreview::setMainDimension(0, 0,ZOOM_1_1);
+      admPreview::setMainDimension(0, 0, ZOOM_1_1);
       if(getPreviewMode()!=ADM_PREVIEW_NONE)
       {
         admPreview::stop();
