@@ -188,7 +188,7 @@ int startAvidemux(int argc, char *argv[])
 
     printf("\n*************************\n");
     printf(" http://www.avidemux.org\n");
-    printf(" Code      : Mean, JSC, Grant Pedersen\n");
+    printf(" Code      : Mean, JSC, Grant Pedersen,eumagga0x2a\n");
     printf(" GFX       : Nestor Di, nestordi@augcyl.org\n");
     printf(" Design    : Jakub Misak\n");
     printf(" FreeBSD   : Anish Mistry, amistry@am-productions.biz\n");
@@ -435,6 +435,13 @@ bool setPrefsDefault(void)
     #else
             prefs->set(VIDEODEVICE,(uint32_t)1); // XV
     #endif
+#endif
+#ifdef __APPLE__
+        prefs->set(AUDIO_DEVICE_AUDIODEVICE,std::string("CoreAudio"));
+    #ifdef USE_OPENGL
+        prefs->set(FEATURES_ENABLE_OPENGL,true);
+        prefs->set(VIDEODEVICE,(uint32_t)5); // QTGL
+    #endif
 #endif
     return true;
 }
