@@ -28,7 +28,7 @@ namespace ADM_qt4Factory
 {
 
 
-class diaElemFloat : public diaElem
+class diaElemFloat : public diaElem,QtFactoryUtils
 {
 protected:
 	int decimals;
@@ -47,10 +47,9 @@ public:
 
 //********************************************************************
 diaElemFloat::diaElemFloat(ELEM_TYPE_FLOAT *intValue,const char *toggleTitle, ELEM_TYPE_FLOAT min, ELEM_TYPE_FLOAT max,const char *tip, int decimals)
-  : diaElem(ELEM_TOGGLE)
+  : diaElem(ELEM_TOGGLE),QtFactoryUtils(toggleTitle)
 {
   param=(void *)intValue;
-  paramTitle=shortkey(toggleTitle);
   this->min=min;
   this->max=max;
   this->tip=tip;
@@ -59,8 +58,7 @@ diaElemFloat::diaElemFloat(ELEM_TYPE_FLOAT *intValue,const char *toggleTitle, EL
 
 diaElemFloat::~diaElemFloat()
 {
-  if(paramTitle)
-    ADM_dealloc(paramTitle);
+ 
 }
 void diaElemFloat::setMe(void *dialog, void *opaque,uint32_t line)
 {
@@ -75,7 +73,7 @@ void diaElemFloat::setMe(void *dialog, void *opaque,uint32_t line)
  box->setSingleStep(0.1);
  box->setValue(*(ELEM_TYPE_FLOAT *)param);
  
- QLabel *text=new QLabel( QString::fromUtf8(this->paramTitle),(QWidget *)dialog);
+ QLabel *text=new QLabel( myQtTitle,(QWidget *)dialog);
  text->setBuddy(box);
 
  QSpacerItem *spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
