@@ -16,9 +16,11 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QUrl>
 #include <QKeyEvent>
+#include <QResizeEvent>
 #include <QGraphicsView>
 #include <QtCore/QDir>
 #include <QMessageBox>
+#include <QClipboard>
 #include "ADM_cpp.h"
 #define MENU_DECLARE
 #include "Q_gui2.h"
@@ -48,6 +50,9 @@ using namespace std;
 #define ADM_SLIDER_REFRESH_PERIOD 500
 #define ADM_LARGE_SCALE     (10LL*1000LL)
 #define ADM_SCALE_INCREMENT (ADM_LARGE_SCALE/100LL)
+// if the dimensions of an autozoomed video are smaller than the available space,
+// don't adjust zoom unless the window has been enlarged beyond a threshold
+#define RESIZE_THRESHOLD 20
 
 #if defined(USE_SDL) && ( !defined(_WIN32) && !defined(__APPLE__))
     #define SDL_ON_LINUX
@@ -83,7 +88,7 @@ extern int A_appendVideo(const char *name);
 int SliderIsShifted=0;
 static void setupMenus(void);
 static int shiftKeyHeld=0;
-static ADM_QSlider *slider=NULL;
+static ADM_mwNavSlider *slider=NULL;
 static int _upd_in_progres=0;
 static int currentFps = 0;
 static int frameCount = 0;
@@ -156,27 +161,10 @@ void MainWindow::comboChanged(int z)
     QObject *obj = sender();
 
     if (obj == ui.comboBoxVideo)
-    {
-        bool b=false;
-        if(ui.comboBoxVideo->currentIndex())
-        {
-            b=true;
-        }
-        ui.pushButtonVideoConf->setEnabled(b);
-        ui.pushButtonVideoFilter->setEnabled(b);
         sendAction (ACT_VIDEO_CODEC_CHANGED) ;
-    }
     else if (obj == ui.comboBoxAudio)
-    {
-        bool b=false;
-        if(ui.comboBoxAudio->currentIndex())
-        {
-            b=true;
-        }
-        ui.pushButtonAudioConf->setEnabled(b);
-        ui.pushButtonAudioFilter->setEnabled(b);
         sendAction (ACT_AUDIO_CODEC_CHANGED) ;
-    }
+    setMenuItemsEnabledState();
 }
 /**
  * \fn sliderValueChanged
@@ -340,6 +328,18 @@ void MainWindow::currentTimeChanged(void)
     this->setFocus(Qt::OtherFocusReason);
 }
 
+/**
+    \fn currentTimeToClipboard
+*/
+void MainWindow::currentTimeToClipboard(void)
+{
+    QString ct = QString();
+    ct = ui.currentTime->text();
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->clear();
+    clipboard->setText(ct);
+}
+
 /**
     \fn ctor
 */
@@ -380,7 +380,7 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
 
     // Slider
     slider=ui.horizontalSlider;
-        ADM_QSlider *qslider=(ADM_QSlider *)slider;
+        ADM_mwNavSlider *qslider=(ADM_mwNavSlider *)slider;
     slider->setMinimum(0);
     slider->setMaximum(ADM_LARGE_SCALE);
 #if 1
@@ -437,10 +437,6 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
     // Build file,... menu
     addScriptEnginesToFileMenu(myMenuFile);
     addScriptShellsToToolsMenu(myMenuTool);
-    buildMyMenu();
-    buildCustomMenu(); // action lists are populated (i.e. buildActionLists() called) within buildCustomMenu()
-    buildButtonLists();
-    // Crash in some cases addScriptReferencesToHelpMenu();
 
     QString rFiles=QString::fromUtf8(QT_TRANSLATE_NOOP("qgui2","Recent Files"));
     QString rProjects=QString::fromUtf8(QT_TRANSLATE_NOOP("qgui2","Recent Projects"));
@@ -452,6 +448,11 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
     connect(this->recentFiles, SIGNAL(triggered(QAction*)), this, SLOT(searchRecentFiles(QAction*)));
     connect(this->recentProjects, SIGNAL(triggered(QAction*)), this, SLOT(searchRecentProjects(QAction*)));
 
+    buildMyMenu();
+    buildCustomMenu(); // action lists are populated (i.e. buildActionLists() called) within buildCustomMenu()
+    buildButtonLists();
+    // Crash in some cases addScriptReferencesToHelpMenu();
+
     this->installEventFilter(this);
     slider->installEventFilter(this);
 
@@ -481,7 +482,14 @@ MainWindow::MainWindow(const vector<IScriptEngine*>& scriptEngines) : _scriptEng
     widgetsUpdateTooltips();
 
     this->adjustSize();
-        QuiTaskBarProgress=createADMTaskBarProgress();
+
+    threshold = RESIZE_THRESHOLD;
+    actZoomCalled = false;
+    ignoreResizeEvent = true;
+    blockResizing = false;
+    blockZoomChanges = true;
+
+    QuiTaskBarProgress=createADMTaskBarProgress();
 }
 /**
     \fn searchToolBar
@@ -559,15 +567,29 @@ bool MainWindow::buildMenu(QMenu *root,MenuEntry *menu, int nb)
                         }else
                             a=insert->addAction(qs);
 #if defined(__APPLE__)
-			a->setMenuRole(QAction::NoRole);
+                        switch(m->event)
+                        {
+                            case(ACT_EXIT):
+                                a->setMenuRole(QAction::QuitRole);
+                                break;
+                            case(ACT_PREFERENCES):
+                                a->setMenuRole(QAction::PreferencesRole);
+                                break;
+                            case(ACT_ABOUT):
+                                a->setMenuRole(QAction::AboutRole);
+                                break;
+                            default:
+			                    a->setMenuRole(QAction::NoRole);
+			            }
 #endif 
                         m->cookie=(void *)a;
-                        if(swpud && m->shortCut=="Up")
-                            a->setShortcut(QKeySequence("Down"));
-                        else if(swpud && m->shortCut=="Down")
-                            a->setShortcut(QKeySequence("Up"));
-                        else if(m->shortCut)
+                        if(m->shortCut)
                         {
+                            if(swpud && !strcmp(m->shortCut,"Up"))
+                                a->setShortcut(Qt::Key_Down);
+                            else if(swpud && !strcmp(m->shortCut,"Down"))
+                                a->setShortcut(Qt::Key_Up);
+
                             if(alt)
                             {
                                 std::string sc="";
@@ -621,6 +643,9 @@ bool MainWindow::buildMyMenu(void)
     connect( ui.menuFile,SIGNAL(triggered(QAction*)),this,SLOT(searchFileMenu(QAction*)));
     buildMenu(ui.menuFile, &myMenuFile[0], myMenuFile.size());
 
+    connect( ui.menuRecent,SIGNAL(triggered(QAction*)),this,SLOT(searchRecentMenu(QAction*)));
+    buildMenu(ui.menuRecent, &myMenuRecent[0], myMenuRecent.size());
+
     connect( ui.menuEdit,SIGNAL(triggered(QAction*)),this,SLOT(searchEditMenu(QAction*)));
     buildMenu(ui.menuEdit, &myMenuEdit[0], myMenuEdit.size());
 
@@ -663,7 +688,6 @@ void MainWindow::buildActionLists(void)
     for(int i=1;i<6;i++)
         ActionsAvailableWhenFileLoaded.push_back(ui.menuFile->actions().at(i));        
 
-    ActionsAvailableWhenFileLoaded.push_back(ui.menuFile->actions().at(2)); // "Save"
     ActionsAvailableWhenFileLoaded.push_back(ui.menuFile->actions().at(9)); // "Information"
 
     for(int i=3;i<11;i++)
@@ -677,16 +701,18 @@ void MainWindow::buildActionLists(void)
         ActionsAvailableWhenFileLoaded.push_back(ui.menuView->actions().at(i));
     }
 
-    for(int i=2;i<ui.toolBar->actions().size();i++)
-    { // disable "Save" and "Information" buttons in the toolbar if no video is loaded
+    ActionsAvailableWhenFileLoaded.push_back(ui.menuVideo->actions().at(1)); // post-processing
+
+    bool canSave=!!ADM_mx_getNbMuxers();
+    for(int i=3-canSave;i<ui.toolBar->actions().size();i++)
+    { // disable "Save" and "Information" buttons in the toolbar if no video is loaded, "Save" also if we've got zero muxers
         ActionsAvailableWhenFileLoaded.push_back(ui.toolBar->actions().at(i));
     }
 
 #define PUSH_FULL_MENU_LOADED(x,tailOffset) for(int i=0;i<ui.x->actions().size()-tailOffset;i++)    ActionsAvailableWhenFileLoaded.push_back(ui.x->actions().at(i));
 #define PUSH_FULL_MENU_PLAYBACK(x,tailOffset) for(int i=0;i<ui.x->actions().size()-tailOffset;i++)    ActionsDisabledOnPlayback.push_back(ui.x->actions().at(i));
 
-    PUSH_FULL_MENU_LOADED(menuVideo,0)
-    PUSH_FULL_MENU_LOADED(menuAudio,0)
+    PUSH_FULL_MENU_LOADED(menuAudio,2)
     PUSH_FULL_MENU_LOADED(menuAuto,0)
     PUSH_FULL_MENU_LOADED(menuGo,0)
 
@@ -716,6 +742,8 @@ void MainWindow::buildActionLists(void)
         for(int i=0;i<recentProjects->actions().size();i++)
             ActionsDisabledOnPlayback.push_back(recentProjects->actions().at(i));
 
+    ActionsDisabledOnPlayback.push_back(ui.menuRecent->actions().back());
+
     // "Always available" below doesn't override the list of menu items disabled during playback
 
 #define PUSH_ALWAYS_AVAILABLE(menu,entry)   ActionsAlwaysAvailable.push_back( ui.menu->actions().at(entry));
@@ -792,6 +820,13 @@ void MainWindow::buildButtonLists(void)
     ADD_PUSHBUTTON_PLAYBACK(pushButtonTime)
     ADD_PUSHBUTTON_PLAYBACK(pushButtonJumpToMarkerA)
     ADD_PUSHBUTTON_PLAYBACK(pushButtonJumpToMarkerB)
+
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonDecoderConf)
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonVideoConf)
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonVideoFilter)
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonAudioConf)
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonAudioFilter)
+    ADD_PUSHBUTTON_PLAYBACK(pushButtonFormatConfigure)
 }
 
 /**
@@ -817,6 +852,9 @@ void MainWindow::setMenuItemsEnabledState(void)
         for(int i=0;i<npb;i++)
             PushButtonsDisabledOnPlayback[i]->setEnabled(false);
 
+        ui.checkBox_TimeShift->setEnabled(false);
+        ui.spinBox_TimeValue->setEnabled(false);
+
         return;
     }
 
@@ -836,6 +874,7 @@ void MainWindow::setMenuItemsEnabledState(void)
     for(int i=0;i<npb;i++)
         PushButtonsAvailableWhenFileLoaded[i]->setEnabled(vid);
 
+    ui.menuFile->actions().at(2)->setEnabled(vid && !!ADM_mx_getNbMuxers()); // disable saving video if there are no muxers
     if(vid)
     {
         undo=video_body->canUndo();
@@ -859,6 +898,74 @@ void MainWindow::setMenuItemsEnabledState(void)
 
     ui.toolButtonPlay->setIcon(QIcon(MKICON(player_play)));
     ui.menuGo->actions().at(0)->setIcon(QIcon(MKICON(player_play)));
+
+    bool haveRecentItems=false;
+    if(recentFiles && recentFiles->actions().size())
+        haveRecentItems=true;
+    if(recentProjects && recentProjects->actions().size())
+        haveRecentItems=true;
+    ui.menuRecent->actions().back()->setEnabled(haveRecentItems);
+
+    updateCodecWidgetControlsState();
+    // actions performed by the code above may result in a window resize event,
+    // which in turn may initiate unwanted zoom changes e.g. when stopping playback
+    // or loading a video with small dimensions, so ignore just this one resize event
+    ignoreResizeEvent = true;
+}
+
+/**
+    \fn updateCodecWidgetControlsState
+*/
+void MainWindow::updateCodecWidgetControlsState(void)
+{
+    bool b=false;
+    // currently only lavc provides some decoder options
+    if(avifileinfo && !strcmp(video_body->getVideoDecoderName(),"Lavcodec"))
+        b=true;
+    ui.pushButtonDecoderConf->setEnabled(b);
+    // take care of the "Decoder Options" item in the menu "Video"
+    ui.menuVideo->actions().at(0)->setEnabled(b);
+
+    b=false;
+    if(ui.comboBoxVideo->currentIndex())
+        b=true;
+    ui.pushButtonVideoConf->setEnabled(b);
+    if(avifileinfo)
+    {
+        ui.pushButtonVideoFilter->setEnabled(b);
+        // take care of the "Filter" item in the menu "Video" as well
+        ui.menuVideo->actions().at(2)->setEnabled(b);
+    }else
+    {
+        ui.pushButtonVideoFilter->setEnabled(false);
+        ui.menuVideo->actions().at(2)->setEnabled(false);
+    }
+
+    b=false;
+    if(avifileinfo && video_body->getDefaultEditableAudioTrack())
+    {
+        ui.menuAudio->actions().at(1)->setEnabled(true);
+        if(ui.comboBoxAudio->currentIndex())
+            b=true;
+    }else
+    {   // disable "Save Audio" item in the menu "Audio" if we have no audio tracks
+        ui.menuAudio->actions().at(1)->setEnabled(false);
+    }
+    ui.pushButtonAudioConf->setEnabled(b);
+    ui.pushButtonAudioFilter->setEnabled(b);
+    // take care of the "Filter" item in the menu "Audio"
+    ui.menuAudio->actions().at(2)->setEnabled(b);
+
+    // reenable the controls below unconditionally after playback
+    ui.checkBox_TimeShift->setEnabled(true);
+    ui.spinBox_TimeValue->setEnabled(true);
+    // disable the "Save" button in the toolbar and the "Configure" button for the output format if we have no muxers
+    b=false;
+    bool gotMuxers=(bool)ADM_mx_getNbMuxers();
+    if(avifileinfo && gotMuxers)
+        b=true;
+    ui.toolBar->actions().at(2)->setEnabled(b);
+    ui.pushButtonFormatConfigure->setEnabled(gotMuxers);
 }
 
 /**
@@ -1060,7 +1167,7 @@ void MainWindow::searchMenu(QAction * action,MenuEntry *menu, int nb)
 
 MKMENU(File)
 MKMENU(Edit)
-//MKMENU(Recent)
+MKMENU(Recent)
 MKMENU(View)
 MKMENU(Tool)
 MKMENU(Go)
@@ -1108,29 +1215,29 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
                 switch (keyEvent->key())
                 {
                     case Qt::Key_Left:
-                        if (keyEvent->modifiers() == Qt::ShiftModifier)
-                            sendAction(ACT_Back1Second);
-                        else if (keyEvent->modifiers() == Qt::ControlModifier)
-                            sendAction(ACT_Back2Seconds);
-                        else if (keyEvent->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier))
+                        if ((keyEvent->modifiers() & Qt::ShiftModifier) && (keyEvent->modifiers() & Qt::ControlModifier))
                             sendAction(ACT_Back4Seconds);
+                        else if (keyEvent->modifiers() & Qt::ShiftModifier)
+                            sendAction(ACT_Back1Second);
+                        else if (keyEvent->modifiers() & Qt::ControlModifier)
+                            sendAction(ACT_Back2Seconds);
                         else
                             sendAction(ACT_PreviousFrame);
 
                         return true;
                     case Qt::Key_Right:
-                        if (keyEvent->modifiers() == Qt::ShiftModifier) 
-                            sendAction(ACT_Forward1Second);
-                        else if (keyEvent->modifiers() == Qt::ControlModifier) 
-                            sendAction(ACT_Forward2Seconds);
-                        else if (keyEvent->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier)) 
+                        if ((keyEvent->modifiers() & Qt::ShiftModifier) && (keyEvent->modifiers() & Qt::ControlModifier))
                             sendAction(ACT_Forward4Seconds);
+                        else if (keyEvent->modifiers() & Qt::ShiftModifier)
+                            sendAction(ACT_Forward1Second);
+                        else if (keyEvent->modifiers() & Qt::ControlModifier)
+                            sendAction(ACT_Forward2Seconds);
                         else 
                             sendAction(ACT_NextFrame);
 
                         return true;
                     case Qt::Key_Up:
-                        if (keyEvent->modifiers() == Qt::ControlModifier)
+                        if (keyEvent->modifiers() & Qt::ControlModifier)
                         {
                             if(!swpud)
                                 sendAction(ACT_Forward1Mn);
@@ -1145,7 +1252,7 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
                         }
                         return true;
                     case Qt::Key_Down:
-                        if (keyEvent->modifiers() == Qt::ControlModifier)
+                        if (keyEvent->modifiers() & Qt::ControlModifier)
                         {
                             if(!swpud)
                                 sendAction(ACT_Back1Mn);
@@ -1159,18 +1266,22 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
                                 sendAction(ACT_PreviousKFrame);
                         }
                         return true;
+                    case Qt::Key_C:
+                        if ((keyEvent->modifiers() & Qt::ShiftModifier) && (keyEvent->modifiers() & Qt::ControlModifier))
+                            currentTimeToClipboard();
+                        return true;
                     case Qt::Key_Shift:
                         shiftKeyHeld = 1;
                         break;
 
                     case Qt::Key_PageUp:
-                                                if (keyEvent->modifiers() == Qt::ControlModifier)
+                                                if (keyEvent->modifiers() & Qt::ControlModifier)
                                                         sendAction(ACT_MarkA);
                                                 else
                                                         sendAction(ACT_GotoMarkA);
                                                 return true;
                     case Qt::Key_PageDown:
-                                                if (keyEvent->modifiers() == Qt::ControlModifier)
+                                                if (keyEvent->modifiers() & Qt::ControlModifier)
                                                         sendAction(ACT_MarkB);
                                                 else
                                                         sendAction(ACT_GotoMarkB);
@@ -1187,6 +1298,63 @@ bool MainWindow::eventFilter(QObject* watched, QEvent* event)
 
             break;
         case QEvent::Resize:
+            if(watched == QuiMainWindows)
+            {
+                if(blockZoomChanges || playing || !avifileinfo)
+                    break;
+                if(ignoreResizeEvent)
+                {
+                    ignoreResizeEvent = false;
+                    break;
+                }
+                uint32_t reqw, reqh;
+                calcDockWidgetDimensions(reqw,reqh);
+
+                uint32_t availw = 1;
+                if(QuiMainWindows->width() > reqw)
+                    availw = QuiMainWindows->width() - reqw;
+                else
+                    break;
+
+                uint32_t availh = 1;
+                if(QuiMainWindows->height() > reqh)
+                    availh = QuiMainWindows->height() - reqh;
+                else
+                    break;
+
+                uint32_t w = avifileinfo->width;
+                uint32_t h = avifileinfo->height;
+                if(!w || !h)
+                    break;
+                // We've got the available space and the video resolution,
+                // now calculate the zoom to fit the video into this space.
+                float widthRatio = (float)availw / (float)w;
+                float heightRatio = (float)availh / (float)h;
+                float zoom = (widthRatio < heightRatio ? widthRatio : heightRatio);
+
+                // Detect if the zoom has been likely set automatically on loading a new video or
+                // changed using a keyboard shortcut. In this case imitate physical friction
+                // requiring the window to be resized beyond certain threshold first.
+                float oldzoom = admPreview::getCurrentZoom();
+                QSize os = static_cast<QResizeEvent*>(event)->oldSize();
+                if(zoom > oldzoom && actZoomCalled)
+                {
+                    if(QuiMainWindows->width() > os.width())
+                        threshold -= QuiMainWindows->width() - os.width();
+                    if(QuiMainWindows->height() > os.height())
+                        threshold -= QuiMainWindows->height() - os.height();
+                    if(threshold > 0)
+                        break;
+                    if(threshold < 0)
+                        threshold = 0;
+                }
+
+                blockResizing = true;
+                admPreview::setMainDimension(w,h,zoom);
+                actZoomCalled = false;
+                admPreview::samePicture(); // required at least for VDPAU
+                blockResizing = false;
+            }
             if (watched == ui.sliderPlaceHolder)
             {
                     thumbSlider->resize(ui.sliderPlaceHolder->width(), 16);
@@ -1276,6 +1444,69 @@ void MainWindow::openFiles(QList<QUrl> urlList)
     }
 }
 
+/**
+    \fn calcDockWidgetDimensions
+    \brief calculate the total width and height occupied by the toolbar and the codec, navigation etc. dock widgets
+*/
+void MainWindow::calcDockWidgetDimensions(uint32_t &width, uint32_t &height)
+{
+    uint32_t reqw=18; // 2 x 9px margin
+    if(ui.codecWidget->isVisible())
+        reqw += ui.codecWidget->frameSize().width() + 6; // with codec widget visible a small extra margin is necessary
+    if(ui.toolBar->orientation()==Qt::Vertical && ui.toolBar->isVisible() && false==ui.toolBar->isFloating())
+        reqw += ui.toolBar->frameSize().width();
+    width = reqw;
+
+    uint32_t reqh=18; // 2 x 9px margin
+    if(ui.menubar->isVisible())
+        reqh += ui.menubar->height();
+    if(ui.toolBar->isVisible() && false==ui.toolBar->isFloating() && ui.toolBar->orientation()==Qt::Horizontal)
+        reqh += ui.toolBar->frameSize().height();
+    if(ui.navigationWidget->isVisible() || ui.selectionWidget->isVisible() || ui.volumeWidget->isVisible() || ui.audioMetreWidget->isVisible())
+       reqh += ui.navigationWidget->frameSize().height();
+    height = reqh;
+}
+
+/**
+    \fn setResizeThreshold
+*/
+void MainWindow::setResizeThreshold(int value)
+{
+    threshold = value;
+}
+
+/**
+    \fn setActZoomCalledFlag
+*/
+void MainWindow::setActZoomCalledFlag(bool called)
+{
+    actZoomCalled = called;
+}
+
+/**
+    \fn setBlockZoomChangesFlag
+*/
+void MainWindow::setBlockZoomChangesFlag(bool block)
+{
+    blockZoomChanges = block;
+}
+
+/**
+    \fn getBlockResizingFlag
+*/
+bool MainWindow::getBlockResizingFlag(void)
+{
+    return blockResizing;
+}
+
+/**
+    \fn setBlockResizingFlag
+*/
+void MainWindow::setBlockResizingFlag(bool block)
+{
+    blockResizing = block;
+}
+
 void MainWindow::previousIntraFrame(void)
 {
     if (ui.spinBox_TimeValue->hasFocus())
@@ -1357,22 +1588,12 @@ int UI_Init(int nargc, char **nargv)
     global_argc=nargc;
     global_argv=nargv;
     ADM_renderLibInit(&UI_Hooks);
-        Q_INIT_RESOURCE(avidemux);
-    Q_INIT_RESOURCE(filter);
 
-#if defined(__APPLE__)
- printf("Setting qt plugin folder\n");
- QDir dir(QApplication::applicationDirPath());
- dir.cdUp();
- dir.cdUp();
- dir.cd("plugins");
- printf("New plugin path =%s\n",dir.absolutePath().toUtf8().constData());
- QApplication::setLibraryPaths(QStringList(dir.absolutePath()));
-#endif
     myApplication=new myQApplication (global_argc, global_argv);
     myApplication->connect(myApplication, SIGNAL(lastWindowClosed()), myApplication, SLOT(quit()));
-        myApplication->connect(myApplication, SIGNAL(aboutToQuit()), myApplication, SLOT(cleanup()));
-        
+    myApplication->connect(myApplication, SIGNAL(aboutToQuit()), myApplication, SLOT(cleanup()));
+    Q_INIT_RESOURCE(avidemux);
+    Q_INIT_RESOURCE(filter);
 
     loadTranslator();
 
@@ -1651,7 +1872,7 @@ void setupMenus(void)
         const char *name=ADM_mx_getDisplayName(i);
         WIDGET(comboBoxFormat)->addItem(name);
     }
-
+    WIDGET(pushButtonFormatConfigure)->setEnabled((bool)nbFormat);
 }
 /*
     Return % of scale (between 0 and 1)
@@ -1967,7 +2188,7 @@ bool UI_setVUMeter( uint32_t volume[6])
     return true;
 }
 /**
-    \fn setDecodeName
+    \fn UI_setDecoderName
 */
 bool UI_setDecoderName(const char *name)
 {
@@ -2026,23 +2247,16 @@ void UI_deiconify( void )
  */
 void UI_resize(uint32_t w,uint32_t h)
 {
-    uint32_t reqw=18; // 2 x 9px margin
-    if(WIDGET(codecWidget)->isVisible())
-        reqw += WIDGET(codecWidget)->frameSize().width() + 6; // with codec widget visible a small extra margin is necessary
-    if(WIDGET(toolBar)->orientation()==Qt::Vertical && WIDGET(toolBar)->isVisible() && false==WIDGET(toolBar)->isFloating())
-        reqw += WIDGET(toolBar)->frameSize().width();
-
-    uint32_t reqh=18; // 2 x 9px margin
-    if(WIDGET(menubar)->isVisible())
-        reqh += WIDGET(menubar)->height();
-    if(WIDGET(toolBar)->isVisible() && false==WIDGET(toolBar)->isFloating() && WIDGET(toolBar)->orientation()==Qt::Horizontal)
-        reqh += WIDGET(toolBar)->frameSize().height();
-    if(WIDGET(navigationWidget)->isVisible() || WIDGET(selectionWidget)->isVisible() || WIDGET(volumeWidget)->isVisible() || WIDGET(audioMetreWidget)->isVisible())
-        reqh += WIDGET(navigationWidget)->frameSize().height();
-
+    if(((MainWindow *)QuiMainWindows)->getBlockResizingFlag())
+        return;
+    uint32_t reqw, reqh;
+    ((MainWindow *)QuiMainWindows)->calcDockWidgetDimensions(reqw,reqh);
     reqw += w;
     reqh += h;
+    UI_setBlockZoomChangesFlag(true);
     QuiMainWindows->resize(reqw,reqh);
+    UI_setBlockZoomChangesFlag(false);
+    ((MainWindow *)QuiMainWindows)->setResizeThreshold(RESIZE_THRESHOLD);
     ADM_info("Resizing the main window to %dx%d px\n",reqw,reqh);
 }
 
@@ -2062,6 +2276,23 @@ void UI_setNeedsResizingFlag(bool resize)
     needsResizing=resize;
 }
 
+/**
+    \fn UI_setBlockZoomChangesFlag
+*/
+void UI_setBlockZoomChangesFlag(bool block)
+{
+    ((MainWindow *)QuiMainWindows)->setBlockZoomChangesFlag(block);
+}
+
+/**
+    \fn UI_resetZoomThreshold
+*/
+void UI_resetZoomThreshold(void)
+{
+    ((MainWindow *)QuiMainWindows)->setResizeThreshold(RESIZE_THRESHOLD);
+    ((MainWindow *)QuiMainWindows)->setActZoomCalledFlag(true);
+}
+
 /**
     \fn UI_setAudioTrackCount
 */
