@@ -10,7 +10,7 @@
 #include <QtCore/QTimer>
 #include <string>
 
-#include "ADM_qslider.h"
+#include "ADM_mwNavSlider.h"
 #include "T_thumbSlider.h"
 #include "ui_gui2.h"
 #include "gui_action.hxx"
@@ -97,6 +97,12 @@ public:
 	void buildRecentProjectMenu(void);
 	void updateActionShortcuts(void);
         void volumeWidgetOperational(void);
+        void calcDockWidgetDimensions(uint32_t &width, uint32_t &height);
+        void setBlockZoomChangesFlag(bool block);
+        bool getBlockResizingFlag(void);
+        void setBlockResizingFlag(bool block);
+        void setResizeThreshold(int value);
+        void setActZoomCalledFlag(bool called);
         static void updateCheckDone(int version, const std::string &date, const std::string &downloadLink);
         static MainWindow *mainWindowSingleton;
 
@@ -164,6 +170,7 @@ public slots:
     void thumbSlider_valueEmitted(int value);
 
     void searchFileMenu(QAction * action);
+    void searchRecentMenu(QAction * action);
     void searchEditMenu(QAction * action);
     void searchVideoMenu(QAction * action);
     void searchAudioMenu(QAction * action);
@@ -202,6 +209,7 @@ protected:
 	void buildRecentMenu(QMenu *menu,std::vector<std::string>files, QAction **actions);
         void buildActionLists(void);
         void buildButtonLists(void);
+        void updateCodecWidgetControlsState(void);
         void widgetsUpdateTooltips(void);
         void searchMenu(QAction * action,MenuEntry *menu, int nb);
 	void searchRecentFiles(QAction *action, QAction **actionList, int firstEventId);
@@ -213,5 +221,13 @@ protected:
 	void dropEvent(QDropEvent *event);
 	void openFiles(QList<QUrl>);
         void changeEvent(QEvent* event);
+        /* Zoom control */
+        bool blockResizing;
+        bool blockZoomChanges;
+        bool ignoreResizeEvent; // suppress unwanted zoom changes
+        bool actZoomCalled; // zoom was set to a pre-defined fraction by a menu action
+        int  threshold; // track how much the window was resized
+        /* allow to copy current pts to clipboard using a keyboard shortcut for convenience */
+        void currentTimeToClipboard(void);
 };
 #endif	// Q_gui2_h
