@@ -1,5 +1,4 @@
 #!/bin/bash
-sh genlog.sh
 mkdir -p install
 rm -f install/*
 echo "#* Preparing 7z svn build *#*"
@@ -9,5 +8,5 @@ echo "Revision : $REV"
 echo "Creating NSIS Package"
 mkdir -p install
 rm -f install/*
-makensis  -DNSIDIR=$PWD avidemux_cross32Qt5.nsi
+makensis -DAPI_VERSION=2.7 -DNSIDIR=$PWD avidemux_cross32Qt5.nsi
 echo "Done"
