@@ -1,7 +1,6 @@
 #!/bin/bash
 mkdir -p install
 rm -f install/*
-sh genlog.sh
 echo "#* Preparing 7z svn build *#*"
 echo "** Getting svn revision **"
 #cp /mingw/bin/iconv.dll /mingw/Release/
@@ -9,5 +8,5 @@ echo "Revision : $REV"
 echo "Creating NSIS Package"
 mkdir -p install
 rm -f install/*
-makensis  -DNSIDIR=$PWD avidemux_cross64Qt5.nsi
+makensis  -DAPI_VERSION=2.7 -DNSIDIR=$PWD avidemux_cross64Qt5.nsi
 echo "Done"
