@@ -1,14 +1,15 @@
+VERSION_APIVERSION, 	//uint32_t
 FEATURES_SWAP_IF_A_GREATER_THAN_B, 	//bool
 FEATURES_SAVEPREFSONEXIT, 	//bool
 FEATURES_IGNORESAVEDMARKERS, 	//bool
 FEATURES_USE_ODML, 	//bool
-FEATURES_USE_SYSTRAY, 	//bool
 FEATURES_REUSE_2PASS_LOG, 	//bool
 FEATURES_AUDIOBAR_USES_MASTER, 	//bool
 FEATURES_THREADING_LAVC, 	//uint32_t
 FEATURES_CPU_CAPS, 	//uint32_t
 FEATURES_MPEG_NO_LIMIT, 	//bool
 FEATURES_ALTERNATE_MP3_TAG, 	//bool
+FEATURES_DXVA2, 	//bool
 FEATURES_VDPAU, 	//bool
 FEATURES_XVBA, 	//bool
 FEATURES_LIBVA, 	//bool
@@ -16,6 +17,18 @@ FEATURES_ENABLE_OPENGL, 	//bool
 FEATURES_CAP_REFRESH_ENABLED, 	//bool
 FEATURES_CAP_REFRESH_VALUE, 	//uint32_t
 FEATURES_SDLDRIVER, 	//string
+FEATURES_USE_LAST_READ_DIR_AS_TARGET, 	//bool
+KEYBOARD_SHORTCUTS_USE_ALTERNATE_KBD_SHORTCUTS, 	//bool
+KEYBOARD_SHORTCUTS_SWAP_UP_DOWN_KEYS, 	//bool
+KEYBOARD_SHORTCUTS_ALT_MARK_A, 	//string
+KEYBOARD_SHORTCUTS_ALT_MARK_B, 	//string
+KEYBOARD_SHORTCUTS_ALT_RESET_MARKERS, 	//string
+KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_A, 	//string
+KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_B, 	//string
+KEYBOARD_SHORTCUTS_ALT_BEGIN, 	//string
+KEYBOARD_SHORTCUTS_ALT_END, 	//string
+UPDATE_ENABLED, 	//bool
+UPDATE_LASTCHECK, 	//uint32_t
 LASTFILES_LASTDIR_READ, 	//string
 LASTFILES_LASTDIR_WRITE, 	//string
 LASTFILES_FILE1, 	//string
@@ -44,3 +57,4 @@ MPEGSPLIT_AUTOSPLIT, 	//uint32_t
 AVISYNTH_AVISYNTH_ALWAYS_ASK, 	//bool
 AVISYNTH_AVISYNTH_DEFAULTPORT, 	//uint32_t
 AVISYNTH_AVISYNTH_LOCALPORT, 	//uint32_t
+RESET_ENCODER_ON_VIDEO_LOAD, 	//bool
