@@ -32,6 +32,8 @@ extern "C" {
 class ADM_vaSurface;
 
 
+#define VA_10BITS_IS_ACTUALL_8BITS 1 // ???
+
 /**
     \class admLibVA
 */
@@ -52,7 +54,7 @@ public:
     static bool         init(GUI_WindowInfo *x);
     static bool         isOperationnal(void);
     static bool         cleanup(void);
-    
+    static VADisplay    getVADisplay();
     /* Setup   */
     static bool         setupConfig(void);
     static bool         setupImageFormat(void);
@@ -60,10 +62,10 @@ public:
     static bool         setupEncodingConfig(void);
     /* Surface */   
     
-static  VAContextID createDecoder(int width, int height, int nbSurface, VASurfaceID *surfaces);
+static  VAContextID createDecoder(VAProfile profile,int width, int height, int nbSurface, VASurfaceID *surfaces);
 static  bool        destroyDecoder(VAContextID decoder);
 
-static  VASurfaceID allocateSurface( int w, int h);
+static  VASurfaceID allocateSurface( int w, int h, int fmt=VA_RT_FORMAT_YUV420);
 static  void        destroySurface(  VASurfaceID surface);
 
 static  VAImage    *allocateNV12Image( int w, int h);
@@ -73,11 +75,11 @@ static  VAImage    *allocateImage( int w, int h);
 
 
 static bool        transfer(VAContextID session, int w, int h,VASurfaceID surface, ADMImage *img,VAImage *tmp,uint8_t *yv12);
-static bool        fillContext(vaapi_context *c);
+static bool        fillContext(VAProfile profile,vaapi_context *c);
 
 // Indirect access through image
 static bool        uploadToImage(ADMImage *src,VAImage *dest );
-static bool        downloadFromImage(ADMImage *src,VAImage *dest );
+static bool        downloadFromImage(ADMImage *src,VAImage *dest ,ADMColorScalerSimple *color=NULL);
 static bool        imageToSurface(VAImage *src,ADM_vaSurface *dest);
 static bool        surfaceToImage(ADM_vaSurface *dst,VAImage *src );
 
@@ -88,9 +90,21 @@ static bool        putX11Surface(ADM_vaSurface *img,int widget,int displayWidth,
 // Direct access
 
 static bool        admImageToSurface( ADMImage *src,ADM_vaSurface *dest);
-static bool        surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src);
+static bool        surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src,ADMColorScalerSimple *color=NULL);
+
+//
+static bool        supported(VAProfile profile);
+
+//-- config for filters --
+static VAConfigID  createFilterConfig();
+static bool        destroyFilterConfig(VAConfigID &id);
+
+//-- config for filters --
+static VAContextID createFilterContext();
+static bool        destroyFilterContext(VAContextID &id);
 
 
+static VADisplay   getDisplay();
 };
 /**
  * \class admLibVAEnc
@@ -125,34 +139,18 @@ class ADM_vaSurface
 public:
     VASurfaceID         surface;
     int                 refCount;
-    decoderFFLIBVA      *parent;
     VAImage             *image;
     int                 w,h;
-    ADM_vaSurface(decoderFFLIBVA *parent,int w, int h)
-    {
-        this->parent=parent;
-        surface=VA_INVALID;
-        refCount=0;
-        this->w=w;
-        this->h=h;
-        image=admLibVA::allocateImage(w,h);
-    }
-    ~ADM_vaSurface()
-    {
-        if(surface!=VA_INVALID)
-        {
-           admLibVA::destroySurface(surface);
-           surface=VA_INVALID;
-        }
-        if(image)
-        {
-            admLibVA::destroyImage(image);
-            image=NULL;
-        }
-    }
+    ADMColorScalerSimple *color10bits;
+    ADM_vaSurface(int w, int h);    
+    ~ADM_vaSurface();
+
+    bool hasValidSurface() {return !(surface==VA_INVALID);}
     bool toAdmImage(ADMImage *image);
     bool fromAdmImage(ADMImage *image);
     
+    static ADM_vaSurface *allocateWithSurface(int w,int h,int fmt=VA_RT_FORMAT_YUV420);
+    
 };
 /**
  * \class ADM_vaEncodingBuffer
