@@ -102,7 +102,7 @@ namespace ADM_coreLibVAEnc
 static bool                  coreLibVAWorking=false;
 
 #define CLEAR(x) memset(&x,0,sizeof(x))
-#define CHECK_ERROR(x) {xError=x;displayXError(#x,ADM_coreLibVA::display,xError);}
+#define CHECK_ERROR(x) {xError=x;displayXError(#x,ADM_coreLibVA::display,xError);if(xError) printf("%d =<%s>\n",xError,vaErrorStr(xError));}
 
 #include "ADM_coreLibVA_test.cpp"
 #include "ADM_bitstream.h"
@@ -170,6 +170,15 @@ static void displayXError(const char *func,const VADisplay dis,const VAStatus er
 
 
 }
+/**
+ * 
+ * @return 
+ */
+VADisplay admLibVA::getVADisplay()
+{
+    return ADM_coreLibVA::display;
+}
+
 /**
  * \fn setupEncodingConfig
  * @return
@@ -693,16 +702,16 @@ bool admLibVA::destroyDecoder(VAContextID session)
  * @param h
  * @return
  */
-VASurfaceID        admLibVA::allocateSurface(int w, int h)
+VASurfaceID        admLibVA::allocateSurface(int w, int h, int fmt)
 {
        int xError;
        CHECK_WORKING(VA_INVALID);
 
-       aprintf("Creating surface %d x %d\n",w,h);
+       aprintf("Creating surface %d x %d (fmt=%d)\n",w,h,fmt);
        VASurfaceID s;
 
         CHECK_ERROR(vaCreateSurfaces(ADM_coreLibVA::display,
-                        VA_RT_FORMAT_YUV420,
+                        fmt,
                         w,h,
                         &s,1,
                         NULL,0));
@@ -755,7 +764,7 @@ void        admLibVA::destroySurface( VASurfaceID surface)
  * @param img
  * @return
  */
-bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
+bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src,ADMColorScalerSimple *color)
 {
     int xError;
     bool r=false;
@@ -818,6 +827,7 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
     {
         case VA_FOURCC_YV12:break;
         case VA_FOURCC_NV12:break;
+        case VA_FOURCC_P010:break;
         default:
             ADM_warning("Unknown format %s\n",fourCC_tostring(vaImage.format.fourcc));
             goto dropIt;
@@ -841,10 +851,29 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
                     break;
                 }
                 case VA_FOURCC_NV12:
+#ifdef VA_10BITS_IS_ACTUALL_8BITS                    
+                case VA_FOURCC_P010:
+#endif                    
                 {
                     dest->convertFromNV12(ptr+vaImage.offsets[0],ptr+vaImage.offsets[1], vaImage.pitches[0], vaImage.pitches[1]);
                     break;
                 }
+#ifndef VA_10BITS_IS_ACTUALL_8BITS                
+                case VA_FOURCC_P010: // It is actually NV12 style All Y, then U/V interleaved
+                {
+                    ADM_assert(color);
+                    ADMImageRef ref(dest->_width,dest->_height);
+                    for(int i=0;i<2;i++)
+                    {
+                            ref._planes[i]= ptr+vaImage.offsets[i];
+                            ref._planeStride[i]=vaImage.pitches[i];
+                    }
+                    ref._planes[2]=NULL;
+                    ref._planeStride[2]=0;
+                    color->convertImage(&ref,dest);                    
+                    break;
+                }
+#endif                
                 default:
                     goto dropIt;
                     break;
@@ -854,8 +883,6 @@ bool        admLibVA::surfaceToAdmImage(ADMImage *dest,ADM_vaSurface *src)
     }
 dropIt:
     CHECK_ERROR(vaDestroyImage (ADM_coreLibVA::display,vaImage.image_id));
-
-
     return r;
 }
 /**
@@ -968,12 +995,12 @@ bool   admLibVA::uploadToImage( ADMImage *src,VAImage *dest)
 }
 
 /**
- * \fn uploadToImage
+ * \fn downloadFromImage
  * @param dest
  * @param src
  * @return
  */
-bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
+bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest,ADMColorScalerSimple *color)
 {
     int xError;
     VASurfaceStatus status;
@@ -999,6 +1026,20 @@ bool   admLibVA::downloadFromImage( ADMImage *src,VAImage *dest)
                         src->duplicate(&ref);
                 }
                 break;
+        case VA_FOURCC_P010: // It is actually NV12 style All Y, then U/V interleaved
+                {
+                    ADM_assert(color);
+                    ADMImageRef ref(src->_width,src->_height);
+                    for(int i=0;i<2;i++)
+                    {
+                            ref._planes[i]= ptr+dest->offsets[i];
+                            ref._planeStride[i]=dest->pitches[i];
+                    }
+                    ref._planes[2]=NULL;
+                    ref._planeStride[2]=0;
+                    color->convertImage(&ref,src);                    
+                    break;
+                }                
         case VA_FOURCC_NV12:
                         src->convertFromNV12(  ptr+dest->offsets[0], ptr+dest->offsets[1],dest->pitches[0],dest->pitches[1]);
                         break;
@@ -1151,10 +1192,10 @@ bool ADM_vaSurface::fromAdmImage (ADMImage *dest)
  * @param h
  * @return
  */
-ADM_vaSurface *ADM_vaSurface::allocateWithSurface(int w,int h)
+ADM_vaSurface *ADM_vaSurface::allocateWithSurface(int w,int h,int fmt)
 {
     ADM_vaSurface *s=new ADM_vaSurface(w,h);
-    s->surface=admLibVA::allocateSurface(w,h);
+    s->surface=admLibVA::allocateSurface(w,h,fmt);
     if(!s->hasValidSurface())
     {
         delete s;
@@ -1191,6 +1232,42 @@ bool ADM_vaImage_cleanupCheck(void)
     return true;
 
 }
+/**
+ * 
+ * @param w
+ * @param h
+ */
+ ADM_vaSurface::ADM_vaSurface(int w, int h)
+{
+    surface=VA_INVALID;
+    refCount=0;
+    this->w=w;
+    this->h=h;
+    image=admLibVA::allocateImage(w,h);
+    color10bits=new ADMColorScalerSimple(w,h,ADM_COLOR_NV12_10BITS,ADM_COLOR_YV12);
+}
+/**
+ * 
+ */ 
+ADM_vaSurface:: ~ADM_vaSurface()
+ {
+     if(surface!=VA_INVALID)
+     {
+        admLibVA::destroySurface(surface);
+        surface=VA_INVALID;
+     }
+     if(image)
+     {
+         admLibVA::destroyImage(image);
+         image=NULL;
+     }
+     if(color10bits)
+     {
+         delete color10bits;
+         color10bits=NULL;
+     }
+ }
+
 /**
  * \fn admLibVa_exitCleanup
  */
@@ -1216,13 +1293,13 @@ bool ADM_vaSurface::toAdmImage(ADMImage *dest)
     case   admLibVA::ADM_LIBVA_NONE: ADM_warning("No transfer supported\n");return false;break;
     case   admLibVA::ADM_LIBVA_DIRECT:
                 //printf("Direct\n");
-                return admLibVA::surfaceToAdmImage(dest,this);
+                return admLibVA::surfaceToAdmImage(dest,this,color10bits);
     case   admLibVA::ADM_LIBVA_INDIRECT_NV12:
     case   admLibVA::ADM_LIBVA_INDIRECT_YV12:
                 //printf("InDirect\n");
                 ADM_assert(this->image);
                 if(admLibVA::surfaceToImage(this,this->image))
-                        return  admLibVA::downloadFromImage(dest,this->image);
+                        return  admLibVA::downloadFromImage(dest,this->image,color10bits);
                 return false;
                 break;
     default:ADM_assert(0);
