@@ -31,9 +31,9 @@ decoderFFSimple::decoderFFSimple (uint32_t w, uint32_t h,uint32_t fcc, uint32_t
     
     AVCodecID id=c->codecId;
     AVCodec *codec=avcodec_find_decoder(id);
-    if(!codec) {GUI_Error_HIG("Codec",QT_TR_NOOP("Internal error finding codec 0x%x"),fcc);ADM_assert(0);} 
+    if(!codec) {GUI_Error_HIG(QT_TRANSLATE_NOOP("adm","Codec"),QT_TRANSLATE_NOOP("adm","Internal error finding codec 0x%x"),fcc);ADM_assert(0);} 
     codecId=id; 
-    ADM_assert(id!=CODEC_ID_NONE);
+    ADM_assert(id!=AV_CODEC_ID_NONE);
     
     _context = avcodec_alloc_context3(codec);
     ADM_assert(_context);
@@ -50,21 +50,23 @@ decoderFFSimple::decoderFFSimple (uint32_t w, uint32_t h,uint32_t fcc, uint32_t
  
     _context->width = _w;
     _context->height = _h;
-    _context->pix_fmt = PIX_FMT_YUV420P;
+    _context->pix_fmt = AV_PIX_FMT_YUV420P;
     
     _context->workaround_bugs=1*FF_BUG_AUTODETECT +0*FF_BUG_NO_PADDING; 
     _context->error_concealment=3; 
     // Hack
-    if(codecId==CODEC_ID_TSCC || codecId==CODEC_ID_CSCD)
+    if(codecId==AV_CODEC_ID_TSCC || codecId==AV_CODEC_ID_CSCD)
     {
         ADM_warning("Forcing bit per coded sample to %d\n",bpp);
          _context->bits_per_coded_sample = bpp;
     }
+     _context->get_format=ADM_FFgetFormat; 
+     _context->opaque=this;
     //
     if (avcodec_open2(_context, codec, NULL) < 0)  
                       { 
                             printf("[lavc] Decoder init: %x video decoder failed!\n",fcc); 
-                            GUI_Error_HIG("Codec","Internal error opening 0x%x",fcc); 
+                            GUI_Error_HIG(QT_TRANSLATE_NOOP("adm","Codec"),QT_TRANSLATE_NOOP("adm","Internal error opening 0x%x"),fcc); 
                             ADM_assert(0); 
                     } 
                     else 
@@ -81,7 +83,7 @@ decoders *admCreateFFSimple(uint32_t w, uint32_t h,uint32_t fcc, uint32_t extraD
     const ffVideoCodec *c=getCodecIdFromFourcc(fcc);
     if(!c) return NULL;
     AVCodecID id=c->codecId;
-    if(id==CODEC_ID_NONE) return NULL;
+    if(id==AV_CODEC_ID_NONE) return NULL;
     return new decoderFFSimple(w,h,fcc,extraDataLen,extraData,bpp);
 }
 /**
@@ -107,6 +109,12 @@ bool admCoreCodecSupports(ADM_CORE_CODEC_FEATURE feat)
     {
         return true;
     }
+#endif
+#ifdef USE_DXVA2
+    if(feat==ADM_CORE_CODEC_FEATURE_DXVA2)
+    {
+        return true;
+    }
 #endif
     return false;
 }
