@@ -286,7 +286,7 @@ int              ADM_coreVideoEncoderFFmpeg::encodeWrapper(AVFrame *in,ADMBitstr
         r= avcodec_encode_video2 (_context,&pkt,in, &gotData);
         if(r<0)
         {
-            ADM_warning("Error %d encoding video\n",r);
+            ADM_warning("Error %d encoding video  \n",r);
             return r;
         }
         if(!gotData)
@@ -325,10 +325,10 @@ bool ADM_coreVideoEncoderFFmpeg::setupInternal(AVCodec *codec)
    if(!configureContext()) {
      return false;
    }
-
+   ADM_info("Opening context\n");
    res=avcodec_open2(_context, codec, NULL);
    if(res<0)
-    {   printf("[ff] Cannot open codec\n");
+    {   ADM_info("[ff] Opening context failed\n");
         return false;
     }
 
