@@ -13,17 +13,61 @@
  ***************************************************************************/
 #include "ADM_cpp.h"
 #include <math.h>
-
+#include <stdlib.h>
 #include "ADM_default.h"
 #include "ADM_Video.h"
 #include "ADM_mkv.h"
 #include "ADM_codecType.h"
 #include "mkv_tags.h"
+#include "ADM_audioXiphUtils.h"
+#include "ADM_vidMisc.h"
+#include "ADM_mkvDeviation.h"
+typedef struct
+{
+    int durationInUs;
+    int num;
+    int den;
+}frameRateStruct;
+
+static const frameRateStruct candidateFrameRate[]=
+{
+   {41708,1001,24000}, // 23.976 fps
+   //{41667,1000,24000}, // 24 fps
+   {40000,1000,25000}, // 25 fps
+   {33367,1001,30000}, // 30 NTSC
+   //{20853,2000,24000}, // 24*2
+   {20854,2002,24000}, // 23976*2
+   {20000,1000,50000}, // 50
+   {16683,1001,60000}, // 60 NTSCs
+   {16667,1000,60000} // 60 fps
+};
+
+static int getStdFrameRate(int interval)
+{
+  int n=sizeof(candidateFrameRate)/sizeof(frameRateStruct);
+  int delta=1000; // 1000 us error allowed
+  int bestMatch=-1;
+  for(int i=0;i<n;i++)
+  {
+      int er=abs(interval-candidateFrameRate[i].durationInUs);
+      if(er<1000) // 10 us error
+      {
+        if(er<delta)
+        {
+          delta=er;
+          bestMatch=i;
+        }
+      }
+  }
+  ADM_info("Best match is %d\n",bestMatch);
+  return bestMatch;
+}
+
 
 /**
     \fn open
     \brief Try to open the mkv file given as parameter
-    
+
 */
 
 uint8_t mkvHeader::open(const char *name)
@@ -59,23 +103,23 @@ uint8_t mkvHeader::open(const char *name)
         uint64_t timeBase=walkAndFind(&father,MKV_TIMECODE_SCALE);
         if(timeBase)
         {
-            ADM_info("TimeBase found : %"PRIu64" ns\n",timeBase);
+            ADM_info("TimeBase found : %" PRIu64" ns\n",timeBase);
             _timeBase=timeBase/1000; // We work in us
         }
   }
   /* --*/
   if(!ebml.simplefind(MKV_SEGMENT,&len,true))
   {
-      printf("[MKV] Cannot find Segment\n");      
+      printf("[MKV] Cannot find Segment\n");
       return false;
   }
   _segmentPosition=ebml.tell();
-  printf("[MKV] found Segment at 0x%llx\n",(uint64_t)_segmentPosition);
+  ADM_info("[MKV] found Segment at 0x%llx\n",(uint64_t)_segmentPosition);
    /* Now find tracks */
   if(ebml.find(ADM_MKV_SECONDARY,MKV_SEGMENT,MKV_SEEK_HEAD,&alen))
   {
        ADM_ebml_file seekHead( &ebml,alen);
-       readSeekHead(&seekHead);       
+       readSeekHead(&seekHead);
   }
   /* Now find tracks */
   /* And analyze them */
@@ -95,7 +139,7 @@ uint8_t mkvHeader::open(const char *name)
   {
     printf("[MKV] Cluster indexing failed\n");
     return 0;
-  }  
+  }
   printf("[MKV]Found %u clusters\n",_clusters.size());
   printf("[MKV] Indexing video\n");
     if(!videoIndexer(&ebml))
@@ -105,30 +149,44 @@ uint8_t mkvHeader::open(const char *name)
     }
   // update some infos
   _videostream.dwLength= _mainaviheader.dwTotalFrames=_tracks[0].index.size();;
+    if(! _videostream.dwLength)
+    {
+        ADM_warning("No image found in this video\n");
+        return 0;
+    }
 
     if(!isH264Compatible(_videostream.fccHandler) && !isMpeg4Compatible(_videostream.fccHandler) && !isMpeg12Compatible(_videostream.fccHandler))
     {
         updateFlagsWithCue();
     }
     _cueTime.clear();
-  
-  
+
+
   _parser=new ADM_ebml_file();
   ADM_assert(_parser->open(name));
   _filename=ADM_strdup(name);
 
   // Now dump some infos about the track
     for(int i=0;i<1+_nbAudioTrack;i++)
-        ADM_info("Track %"PRIu32" has an index size of %d entries\n",i,_tracks[i].index.size());
+        ADM_info("Track %" PRIu32" has an index size of %d entries\n",i,_tracks[i].index.size());
 
 
+  if(isVC1Compatible(_videostream.fccHandler))
+  {
+      int       nb=_tracks[0].index.size();
+      mkvTrak   *vid=_tracks;
+
+      ADM_warning("Deleting  timestamps. For VC1, they are often wrong\n");
+      for(int i=1;i<nb-1;i++)
+          vid->index[i].Pts=ADM_NO_PTS;
+  }
   // Delay frames + recompute frame duration
 // now that we have a good frameduration and max pts dts difference, we can set a proper DTS for all video frame
     uint32_t ptsdtsdelta, mindelta;
     bool hasBframe;
   ComputeDeltaAndCheckBFrames(&mindelta, &ptsdtsdelta,&hasBframe);
-  
-  
+
+
   int last=_tracks[0].index.size();
   uint64_t increment=_tracks[0]._defaultFrameDuration;
   uint64_t lastDts=0;
@@ -165,7 +223,7 @@ uint8_t mkvHeader::open(const char *name)
         }
         if(enforePtsGreaterThanDts)
         {
-                ADM_info("Have to delay by %"PRIu32" ms so that PTS>DTS\n",enforePtsGreaterThanDts);
+                ADM_info("Have to delay by %" PRIu64" us so that PTS>DTS\n",enforePtsGreaterThanDts);
                 for(int i=0;i<_nbAudioTrack+1;i++)
                 delayTrack(i,&(_tracks[i]),enforePtsGreaterThanDts);
         }
@@ -186,7 +244,7 @@ uint8_t mkvHeader::open(const char *name)
           printf("[MKV] Video Track duration for %u ms\n",duration32);
           // Useless.....
 
-        
+
 
           for(int i=0;i<_nbAudioTrack;i++)
           {
@@ -206,7 +264,6 @@ uint8_t mkvHeader::open(const char *name)
         _audioStreams[i]=ADM_audioCreateStream(&(_tracks[1+i].wavHeader), _access[i]);;
         _audioStreams[i]->setLanguage(_tracks[1+i].language);
     }
-  //dumpVideoIndex(200);
   printf("[MKV]Matroska successfully read\n");
   return 1;
 }
@@ -226,12 +283,44 @@ bool mkvHeader::delayTrack(int index,mkvTrak *track, uint64_t value)
     }
     return true;
 }
+/**
+    \fn checkDeviation
+    \brief Bypass the 1ms accuracy by making sure all the frames are in the form PTS=offset + N*frameInterval
+*/
+bool mkvHeader::enforceFixedFrameRate(int num, int den)
+{
+  mkvTrak *track=_tracks;
+  int nb=track->index.size();
+  double dHalf=(500000.*(double)num)/((double)den);
+  int half=dHalf-1; // half interval in us
+  int first=0;
+  int bad=0;
+  int good=0;
+  while(  track->index[first].Pts==ADM_NO_PTS && first<nb) first++; // we should have some at least
+  uint64_t zero= track->index[first].Pts;
+  ADM_info("Num=%d Den=%d half=%d zero=%d first=%d\n",num,den,half,(int)zero,first);
+  for(int i=first+1;i<nb;i++)
+  {
+    uint64_t pts=track->index[i].Pts;
+    if(pts<zero) continue;
+    pts-=zero;
+    double dmultiple=(pts+half);
+    dmultiple*=den;
+    dmultiple/=(1000000.*(double)num);
+    uint64_t multiple=(uint64_t)dmultiple;
+    int64_t reconstructed=(multiple*1000000*num)/den+zero;
+    //printf("frame %d multiple = %d, pts=%d, reconstructed=%d,delta = %d\n",i,(int)multiple,(int)pts,(int)reconstructed,(int)(pts-reconstructed));
+    track->index[i].Pts=reconstructed;
+  }
+  return true;
+}
 /**
     \fn delayFrameIfBFrames
     \brief recompute max pts/dts distance and delay all tracks if needed
     we dont want a negative dts.
     \return maxdelta in us
 */
+
 bool mkvHeader::ComputeDeltaAndCheckBFrames(uint32_t *minDeltaX, uint32_t *maxDeltaX, bool *bFramePresent)
 {
     mkvTrak *track=_tracks;
@@ -240,13 +329,17 @@ bool mkvHeader::ComputeDeltaAndCheckBFrames(uint32_t *minDeltaX, uint32_t *maxDe
     int64_t delta,maxDelta=0;
     int64_t minDelta=100000000;
     *bFramePresent=false;
+    int nbValidDts=0;
+
+
+
     if(nb>1)
     {
         bool monotone=true;
         uint64_t pts=track->index[0].Pts;
         for(int i=1;i<nb;i++)
         {
-            if(track->index[i].Pts<pts) 
+            if(track->index[i].Pts<pts)
             {
                 monotone=false;
                 break;
@@ -255,59 +348,194 @@ bool mkvHeader::ComputeDeltaAndCheckBFrames(uint32_t *minDeltaX, uint32_t *maxDe
         }
         if(monotone==true)
         {
-            ADM_info("PTS is monotonous, probably no bframe\n");        
+            ADM_info("PTS is monotonous, probably no bframe\n");
             *bFramePresent=false;
         }else
         {
             ADM_info("PTS is not monotonous, there are bframe\n");
             *bFramePresent=true;
         }
-    }
 
-    if(nb>1)
-    {
+
         // Search minimum and maximum between 2 frames
         // the minimum will give us the maximum fps
         // the maximum will give us the max PTS-DTS delta so that we can compute DTS
-        for(int i=0;i<nb-1;i++) 
+        for(int i=0;i<nb-1;i++)
         {
+            if(track->index[i].Dts!=ADM_NO_PTS)
+                nbValidDts++;
             if(track->index[i].flags==AVI_B_FRAME) nbBFrame++;
+            if(track->index[i+1].Pts==ADM_NO_PTS || track->index[i].Pts==ADM_NO_PTS)
+                continue;
+
             delta=(int64_t)track->index[i+1].Pts-(int64_t)track->index[i].Pts;
             if(delta<0) delta=-delta;
+            if(!delta)
+            {
+                ADM_warning("Duplicate PTS...(%d and %d,size=%d %d)\n",i,i+1,track->index[i].size,track->index[i+1].size);
+                continue;
+            }
             if(delta<minDelta) minDelta=delta;
             if(delta>maxDelta) maxDelta=delta;
-            //printf("\/=%"PRId64" Min %"PRId64" MAX %"PRId64"\n",delta,minDelta,maxDelta);
+            //printf("\/=%" PRId64" Min %" PRId64" MAX %" PRId64"\n",delta,minDelta,maxDelta);
         }
     }
     if(nbBFrame) *bFramePresent=true;
-    ADM_info("Minimum delta found %"PRId64" us\n",minDelta);
-    ADM_info("Maximum delta found %"PRId64" us\n",maxDelta);
-    if(minDelta)
+
+    int stdFrameRate=getStdFrameRate(track->_defaultFrameDuration);
+
+    int num= _videostream.dwScale;
+    int den= _videostream.dwRate;
+    int skipped=0;
+    
+    int deviation=0;
     {
-        if(minDelta<track->_defaultFrameDuration && labs((long int)minDelta-(long int)track->_defaultFrameDuration)>1000)
+        // Initialize deviation
+        // 
+        mkvDeviation devEngine(nb);      
+        int first=0;
+        while(  track->index[first].Pts==ADM_NO_PTS && first<nb) 
+              first++; // we should have some at least
+        uint64_t zero= track->index[first].Pts;
+        ADM_info("Num=%d Den=%d zero=%d first=%d\n",num,den,(int)zero,first);
+        for(int i=first;i<nb;i++)
         {
-            ADM_info("Changing default frame duration from %"PRIu64" to %"PRIu64" us\n",
-                    track->_defaultFrameDuration,minDelta);
-            track->_defaultFrameDuration=minDelta;
-            // updated fps also
-            float f=minDelta;
-            f=1000000./f;
-            _videostream.dwScale=1000;
-            _videostream.dwRate=(uint32_t)(f*1000.);
-        }else
+          uint64_t pts=track->index[i].Pts;
+          if(pts==ADM_NO_PTS) continue;
+          if(pts<zero) continue;
+            
+          devEngine.add(pts-zero);
+        }
+        devEngine.sort();
+        ADM_info("Checking deviation for native %d %d\n", _videostream.dwScale,   _videostream.dwRate);
+        deviation=devEngine.computeDeviation(  _videostream.dwScale,   _videostream.dwRate,skipped);
+        
+        int deviationMinDelta=100000000;
+        int minDeltaSkip;
+        if(minDelta)
         {
-            ADM_info("Keeping default frame duration  %"PRIu64" us\n", track->_defaultFrameDuration);
+            ADM_info("Checking deviation for minDelta %d %d\n",minDelta,1000000);
+            deviationMinDelta =devEngine.computeDeviation(  minDelta,1000000,minDeltaSkip   );
+        }
+        ADM_info("Deviation        = %d\n",deviation);
+        ADM_info("DeviationMinDelta = %d\n",deviationMinDelta);
+        ADM_info("Deviation skip    = %d\n",minDeltaSkip);
+    
+        if(minDeltaSkip>skipped*3) // we are skipping a lot more frame, fps too high
+        {
+            ADM_info("Too many skipped frames, dropping candidates\n");
+            deviationMinDelta=deviation*2;
+        }
+                
+        if(minDelta)
+        {
+            bool preferMinDelta=false;
+            // Hack to rescale double fps, ugly, might cause problem
+            if(deviationMinDelta==deviation)
+            {
+                // min num/den > std num/den
+                if(minDelta*_videostream.dwRate >  _videostream.dwScale*1000000*1.5)
+                {
+                    ADM_info("Both are equal but prefering minDelta\n");
+                    preferMinDelta=true;
+                }
+            }
+            //
+            if(deviationMinDelta<deviation || preferMinDelta)
+            {
+                den=1000*1000;
+                num=minDelta;
+                deviation=deviationMinDelta;
+                skipped=minDeltaSkip;
+                ADM_info("Min delta is better\n");
+            }
+        }
+
+        // Check std value too
+        if(stdFrameRate!=-1)
+        {
+            int stdSkip;
+            const frameRateStruct *fr=&(candidateFrameRate[stdFrameRate]);
+            ADM_info("Checking deviation for stdFrameRate=%d:%d\n",fr->num,fr->den);
+            int deviationStd=devEngine.computeDeviation(fr->num,fr->den,stdSkip);
+            ADM_info("Deviation for stdFrameRate(%d) =%d\n",stdFrameRate,deviationStd);
+            if(deviationStd<deviation && stdSkip<skipped*3)
+            {
+              num=fr->num;
+              den=fr->den;
+              deviation=deviationStd;
+              ADM_info("Std frame rate is better\n");
+            }
+        }
+    }
+    ADM_info("Old default duration    %" PRId64" us\n",track->_defaultFrameDuration);
+    if(!deviation)
+    {
+        ADM_info("We are within margin, recomputing timestamp with exact value (%d vs %d)\n",num,den);
+        enforceFixedFrameRate(num,den);
+        // do it again, the old may not be valid 
+        // Search minimum and maximum between 2 frames
+        // the minimum will give us the maximum fps
+        // the maximum will give us the max PTS-DTS delta so that we can compute DTS
+        maxDelta=0;
+        minDelta=100000000;
+        for(int i=0;i<nb-1;i++)
+        {
+            if(track->index[i].Dts!=ADM_NO_PTS)
+                nbValidDts++;
+            if(track->index[i].flags==AVI_B_FRAME) nbBFrame++;
+            if(track->index[i+1].Pts==ADM_NO_PTS || track->index[i].Pts==ADM_NO_PTS)
+                continue;
+
+            delta=(int64_t)track->index[i+1].Pts-(int64_t)track->index[i].Pts;
+            if(delta<0) delta=-delta;
+            if(!delta)
+            {
+                ADM_warning("Duplicate PTS...%s (%d and %d,size=%d %d)\n",ADM_us2plain(track->index[i].Pts),i,i+1,track->index[i].size,track->index[i+1].size);
+                continue;
+            }
+            if(delta<minDelta) minDelta=delta;
+            if(delta>maxDelta) maxDelta=delta;
+            //printf("\/=%" PRId64" Min %" PRId64" MAX %" PRId64"\n",delta,minDelta,maxDelta);
         }
 
     }
-    ADM_info("First frame pts     %"PRId64" us\n",track->index[0].Pts);
+
+    //if( num!= _videostream.dwScale ||  den!= _videostream.dwRate)
+    {
+        ADM_info("New framerate values : %d:%d\n",num,den);
+        _videostream.dwScale=num;
+        _videostream.dwRate=den;
+        double f=num;
+        f=f*1000000.;
+        f/=den;
+        track->_defaultFrameDuration=f;
+       
+
+    }
+
+    ADM_info("New default duration    %" PRId64" us\n",track->_defaultFrameDuration);
+
+
+
+    ADM_info("First frame pts     %" PRId64" us\n",track->index[0].Pts);
+
+    if(nbValidDts<3)
+    {
+            ADM_warning("Not enough valid DTS (%d)\n",(int)nbValidDts);
+            *minDeltaX=minDelta;
+            *maxDeltaX=0;
+            return false;
+    }
+
+
     uint64_t adj=0;
     int limit=32;
     if(limit>nb) limit=nb;
     // Pts must be >= maxDelta for all frames, the first 32 will do
     for(int i=0;i<limit;i++)
     {
-        if(maxDelta>track->index[i].Pts) 
+        if(maxDelta>track->index[i].Pts)
         {
             uint64_t newAdj=maxDelta-track->index[i].Pts;
             if(newAdj>adj) adj=newAdj;
@@ -315,8 +543,8 @@ bool mkvHeader::ComputeDeltaAndCheckBFrames(uint32_t *minDeltaX, uint32_t *maxDe
     }
     if(adj) // need to correct
     {
-        ADM_info("Delaying video by %"PRIu64" us\n",adj);
-        ADM_info("[mkv] Delaying audio by %"PRIu64" us\n",adj);
+        ADM_info("Delaying video by %" PRIu64" us\n",adj);
+        ADM_info("[mkv] Delaying audio by %" PRIu64" us\n",adj);
         for(int i=0;i<_nbAudioTrack+1;i++)
             delayTrack(i,&(_tracks[i]),adj);
     }
@@ -376,14 +604,14 @@ bool mkvHeader::goBeforeAtomAtPosition(ADM_ebml_file *parser, uint64_t position,
     }
     if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
     {
-      printf("[MKV/SeekHead] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+      printf("[MKV/SeekHead] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
       return false;
     }
     if(id!=searchedId)
     {
         printf("Found %s instead of %s, ignored \n",ss,txt);
         return false;
-    }    
+    }
     outputLen=len;
     return true;
 }
@@ -398,20 +626,20 @@ bool mkvHeader::analyzeTracks(ADM_ebml_file *parser)
   uint64_t id;
   const char *ss;
   ADM_MKV_TYPE type;
-  
+
   if(!goBeforeAtomAtPosition(parser, _trackPosition,len, MKV_TRACKS,"MKV_TRACKS"))
   {
       ADM_warning("Cannot go to the TRACKS atom\n");
       return false;
   }
-  
+
     ADM_ebml_file father( parser,len);
     while(!father.finished())
     {
       father.readElemId(&id,&len);
       if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
       {
-        printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+        printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
         father.skip(len);
         continue;
       }
@@ -442,7 +670,7 @@ uint8_t mkvHeader::walk(void *seed)
       father->readElemId(&id,&len);
       if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
       {
-        printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+        printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
         father->skip(len);
         continue;
       }
@@ -454,10 +682,10 @@ uint8_t mkvHeader::walk(void *seed)
                   printf("%s skipped\n",ss);
                   break;
         case ADM_MKV_TYPE_UINTEGER:
-                  printf("%s:%"PRIu64"\n",ss,father->readUnsignedInt(len));
+                  printf("%s:%" PRIu64"\n",ss,father->readUnsignedInt(len));
                   break;
         case ADM_MKV_TYPE_INTEGER:
-                  printf("%s:%"PRId64"\n",ss,father->readSignedInt(len));
+                  printf("%s:%" PRId64"\n",ss,father->readSignedInt(len));
                   break;
         case ADM_MKV_TYPE_STRING:
         {
@@ -492,7 +720,7 @@ uint64_t mkvHeader::walkAndFind(void *seed,MKV_ELEM_ID searched)
       father->readElemId(&id,&len);
       if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
       {
-        printf("[MKV] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+        printf("[MKV] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
         father->skip(len);
         continue;
       }
@@ -508,11 +736,11 @@ uint64_t mkvHeader::walkAndFind(void *seed,MKV_ELEM_ID searched)
                   uint64_t v=father->readUnsignedInt(len);
                   if(id==searched)
                         value=v;
-                  printf("%s:%"PRIu64"\n",ss,v);
+                  printf("%s:%" PRIu64"\n",ss,v);
                   }
                   break;
         case ADM_MKV_TYPE_INTEGER:
-                  printf("%s:%"PRId64"\n",ss,father->readSignedInt(len));
+                  printf("%s:%" PRId64"\n",ss,father->readSignedInt(len));
                   break;
         case ADM_MKV_TYPE_STRING:
         {
@@ -594,11 +822,12 @@ uint8_t mkvHeader::close(void)
   _currentAudioTrack=0;
   _access=NULL;
   _audioStreams=NULL;
-  
+
   readBuffer=NULL;
   _cuePosition=0;
   _segmentPosition=0;
   _trackPosition=0;
+  _H264Recovery=16;
 }
 /**
     \fn ~mkvHeader
@@ -695,6 +924,25 @@ uint8_t  mkvHeader::getExtraHeaderData(uint32_t *len, uint8_t **data)
                 *data=_tracks[0].extraData;
                 return 1;
 }
+/**
+ *
+ * @param hd
+ * @return
+ */
+static int xypheLacingRead(uint8_t **hd)
+{
+      int x=0;
+      uint8_t *p=*hd;
+      while(*p==0xff)
+      {
+        x+=0xff;
+        p++;
+      }
+      x+=*p;
+      p++;
+      *hd=p;
+      return x;
+}
 
 /**
     \fn mkreformatVorbisHeader
@@ -702,55 +950,19 @@ uint8_t  mkvHeader::getExtraHeaderData(uint32_t *len, uint8_t **data)
 */
 uint8_t mkvHeader::reformatVorbisHeader(mkvTrak *trk)
 {
-  /*
-  The private data contains the first three Vorbis packet in order. The lengths of the packets precedes them. The actual layout is:
-Byte 1: number of distinct packets '#p' minus one inside the CodecPrivate block. This should be '2' for current Vorbis headers.
-Bytes 2..n: lengths of the first '#p' packets, coded in Xiph-style lacing. The length of the last packet is the length of the CodecPrivate block minus the lengths coded in these bytes minus one.
-Bytes n+1..: The Vorbis identification header, followed by the Vorbis comment header followed by the codec setup header.
-  */
-  uint8_t *oldata=trk->extraData;
-  uint32_t oldlen=trk->extraDataLen;
-  uint32_t len1,len2,len3;
-  uint8_t *head;
-      if(*oldata!=2) {printf("[MKV] weird audio, expect problems\n");return 0;}
-      // First packet length
-      head=oldata+1;
-#define READ_LEN(x) \
-      x=0; \
-      while(*head==0xff)  \
-      { \
-        x+=0xff; \
-        head++; \
-      } \
-      x+=*head++;
-
-      READ_LEN(len1);
-      READ_LEN(len2);
-      len3=oldata+oldlen-head;
-      if(len3<=len1+len2)
-      {
-        printf("Error in vorbis header, len3 too small %u %u / %u\n",len1,len2,len3);
-        return 0;
-      }
-      len3-=(len1+len2);
-      printf("Found packet len : %u %u %u, total size %u\n",len1,len2,len3,oldlen);
-      // Now build our own packet...
-      uint8_t *nwdata=new uint8_t[len1+len2+len3+sizeof(uint32_t)*3];
-      uint32_t nwlen=len1+len2+len3+sizeof(uint32_t)*3;
-      uint8_t *cp=nwdata+sizeof(uint32_t)*3;
-      memcpy(cp,head,len1);
-      memcpy(cp+len1,head+len1,len2);
-      memcpy(cp+len1+len2,head+len1+len2,len3);
-
-      uint32_t *h=(uint32_t *)nwdata;
-      h[0]=len1;
-      h[1]=len2;
-      h[2]=len3;
-      // Destroy old datas
-      delete [] oldata;
-      trk->extraData=nwdata;
-      trk->extraDataLen=nwlen;
-  return 1;
+    uint8_t *newExtra=NULL;
+    int newExtraLen=0;
+    bool r=ADMXiph::xiphExtraData2Adm(trk->extraData,trk->extraDataLen,&newExtra,&newExtraLen);
+    if(!r)
+    {
+        ADM_warning("Cannot reformat vorbis extra data\n");
+        return false;
+    }
+    // Destroy old datas
+    delete [] trk->extraData;
+    trk->extraData=newExtra;
+    trk->extraDataLen=newExtraLen;
+    return 1;
 }
 /**
     \fn getNbAudioStreams
@@ -792,13 +1004,13 @@ uint8_t                 mkvHeader::getAudioStream(uint32_t i,ADM_audioStream  **
 bool    mkvHeader::getPtsDts(uint32_t frame,uint64_t *pts,uint64_t *dts)
 {
      ADM_assert(_parser);
-     if(frame>=_tracks[0].index.size()) 
+     if(frame>=_tracks[0].index.size())
      {
-            printf("[MKV] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,(uint32_t)_tracks[0].index.size());
+            printf("[MKV] Frame %" PRIu32" exceeds # of frames %" PRIu32"\n",frame,(uint32_t)_tracks[0].index.size());
             return false;
      }
     mkvIndex *dx=&(_tracks[0].index[frame]);
-    
+
     *dts=dx->Dts; // FIXME
     *pts=dx->Pts;
     return true;
@@ -809,13 +1021,13 @@ bool    mkvHeader::getPtsDts(uint32_t frame,uint64_t *pts,uint64_t *dts)
 bool    mkvHeader::setPtsDts(uint32_t frame,uint64_t pts,uint64_t dts)
 {
       ADM_assert(_parser);
-     if(frame>=_tracks[0].index.size()) 
+     if(frame>=_tracks[0].index.size())
      {
-            printf("[MKV] Frame %"PRIu32" exceeds # of frames %"PRIu32"\n",frame,(uint32_t)_tracks[0].index.size());
+            printf("[MKV] Frame %" PRIu32" exceeds # of frames %" PRIu32"\n",frame,(uint32_t)_tracks[0].index.size());
             return false;
      }
     mkvIndex *dx=&(_tracks[0].index[frame]);
-    
+
     dx->Dts=dts; // FIXME
     dx->Pts=pts;
     return true;
@@ -832,8 +1044,8 @@ bool    mkvHeader::readSeekHead(ADM_ebml_file *body)
     while(!body->finished())
     {
         if(!body->simplefind(MKV_SEEK,&vlen,false))
-             break;         
-        ADM_ebml_file item(body,vlen);              
+             break;
+        ADM_ebml_file item(body,vlen);
         uint64_t id;
         ADM_MKV_TYPE type;
         const char *ss;
@@ -841,34 +1053,36 @@ bool    mkvHeader::readSeekHead(ADM_ebml_file *body)
         item.readElemId(&id,&len);
         if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
         {
-          printf("[MKV/SeekHead] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+          printf("[MKV/SeekHead] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
           return false;
         }
         if(id!=MKV_ID)
         {
           printf("Found %s in CUES, ignored \n",ss);
           item.skip(len);
-          return false;
+          //return false;
+          continue;
         }
         // read id
         uint64_t t=item.readEBMCode_Full();
         if(!ADM_searchMkvTag( (MKV_ELEM_ID)t,&ss,&type))
         {
-          printf("[MKV/SeekHead] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+          printf("[MKV/SeekHead] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
           return false;
         }
         ADM_info("Found entry for %s\n",ss);
         item.readElemId(&id,&len);
         if(!ADM_searchMkvTag( (MKV_ELEM_ID)id,&ss,&type))
         {
-          printf("[MKV/SeekHead] Tag 0x%"PRIx64" not found (len %"PRIu64")\n",id,len);
+          printf("[MKV/SeekHead] Tag 0x%" PRIx64" not found (len %" PRIu64")\n",id,len);
           return false;
         }
         if(id!=MKV_SEEK_POSITION)
         {
           printf("Found %s in CUES, ignored \n",ss);
           item.skip(len);
-          return false;
+          //return false;
+          continue;
         }
         uint64_t position=item.readUnsignedInt(len);
         switch(t)
@@ -884,7 +1098,7 @@ bool    mkvHeader::readSeekHead(ADM_ebml_file *body)
             default:
                     break;
         }
-              
+
     }
     ADM_info("Parsing SeekHead done successfully\n");
     if(!_trackPosition )
