@@ -21,7 +21,9 @@
 #define __3GPHEADER__
 #include "ADM_Video.h"
 #include "ADM_atom.h"
-
+#include <vector>
+/**
+ */
 class MPsampleinfo
 {
   public:
@@ -49,7 +51,8 @@ class MPsampleinfo
       MPsampleinfo(void);
       ~MPsampleinfo(void);
 };
-
+/**
+ */
 typedef struct MP4Index
 {
 	uint64_t offset; // Offset in file to get frame
@@ -59,6 +62,9 @@ typedef struct MP4Index
     uint64_t dts; // Delta in frame between pts & dts
 
 }MP4Index;
+class mp4Fragment;
+/**
+ */
 class MP4Track
 {
 public:
@@ -69,18 +75,23 @@ public:
     uint32_t    extraDataSize;
     uint8_t     *extraData;
     WAVHeader   _rdWav;
+    std::vector <mp4Fragment>     fragments;
                 MP4Track(void);
                 ~MP4Track();
 };
 
-
+/**
+ */
 class ADM_mp4AudioAccess : public ADM_audioAccess
 {
 protected:
-                uint32_t 					_nb_chunks;
-              	uint32_t 					_current_index;
-                MP4Index 					*_index;
-                FILE						*_fd; 
+                uint32_t        _nb_chunks;
+                uint32_t        _current_index;
+                MP4Index        *_index;
+                FILE            *_fd;
+                // Suppress repeated debug messages from getPacket
+                ADMCountdown    *_msg_ratelimit;
+                uint32_t        _msg_counter;
 public:
                                   ADM_mp4AudioAccess(const char *name,MP4Track *trak) ;
                 virtual           ~ADM_mp4AudioAccess();
@@ -102,25 +113,83 @@ public:
                 virtual uint64_t  getPos(){ADM_assert(0); return 0;};
                                     /// Go to a given time
                 virtual bool      goToTime(uint64_t timeUs);
-                virtual bool    getPacket(uint8_t *buffer, uint32_t *size, uint32_t maxSize,uint64_t *dts);
+                virtual bool      getPacket(uint8_t *buffer, uint32_t *size, uint32_t maxSize,uint64_t *dts);
 };
 
 
 #define _3GP_MAX_TRACKS 8
 #define VDEO _tracks[0]
 #define ADIO _tracks[nbAudioTrack+1]._rdWav
+/**
+ * 
+ */
+class mp4TrafInfo
+{
+public:
+    uint32_t trackID;
+    uint64_t baseOffset;
+    uint64_t baseDts;
+    uint32_t sampleDesc;
+    uint32_t defaultDuration;
+    uint32_t defaultSize;
+    uint32_t defaultFlags;
+    bool     emptyDuration;
+    bool     baseIsMoof;
+    
+    mp4TrafInfo()
+    {
+        baseOffset=baseDts=0;
+        trackID=0;
+        sampleDesc=defaultDuration=defaultSize=defaultFlags=0;
+        emptyDuration=baseIsMoof=false;
+    }
+};
+/**
+ * 
+ */
+class mp4Fragment
+{
+public:
+        mp4Fragment()
+        {
+            duration=0;
+            size=0;
+            flags=0;
+            composition=0;
+            offset=0;
+        }
+        uint32_t duration;
+        uint32_t size;
+        uint32_t flags;
+        int32_t  composition;
+        uint64_t offset;
+};
+
 /**
     \class MP4Header
 */
 class MP4Header         :public vidHeader
 {
 protected:
+        enum Mp4Flavor
+        {
+            Mp4Regular,
+            Mp4Dash
+        };
+protected:
+          
+          bool                          indexVideoFragments(int trackNo);
+          bool                          indexAudioFragments(int trackNo);
           /*****************************/
           uint64_t                      delayRelativeToVideo;
           uint8_t                       lookupMainAtoms(void *tom);
           void                          parseMvhd(void *tom);
           uint8_t                       parseTrack(void *ztom);
           uint8_t                       parseElst(void *tom,uint32_t trackType);
+          bool                          parseMoof(adm_atom &son);
+          bool                          parseTraf(adm_atom &son,uint64_t moofStart);
+          int                           lookupIndex(int desc)          ;
+          bool                          parseTrun(int trackNo,adm_atom &son,const mp4TrafInfo &info);
           uint8_t                       decodeVideoAtom(void *ztom);
           uint8_t                       parseMdia(void *ztom,uint32_t *trackType,uint32_t w, uint32_t h);
           uint8_t                       parseEdts(void *ztom,uint32_t trackType);
@@ -146,8 +215,9 @@ protected:
         uint8_t                       _reordered;		
         FILE                          *_fd;
         MP4Track                      _tracks[_3GP_MAX_TRACKS];
-        int64_t                      _audioDuration;
+        int64_t                       _audioDuration;
         uint32_t                      _currentAudioTrack;
+        Mp4Flavor                     _flavor;
         uint8_t                       parseAtomTree(adm_atom *atom);
         ADM_mp4AudioAccess            *audioAccess[_3GP_MAX_TRACKS-1];
         ADM_audioStream               *audioStream[_3GP_MAX_TRACKS-1];
@@ -155,17 +225,18 @@ protected:
         bool                          refineAudio(WAVHeader *head,uint32_t extraLen, uint8_t *extra);
         bool                          shiftTimeBy(uint64_t shift);
         bool                          shiftAudioTimeBy(uint64_t shift);
+        bool                          checkDuplicatedPts(void);
          /*********************************/
 	uint32_t                         readPackedLen(adm_atom *tom );
 	
 public:
-virtual   void 	                Dump(void) {};
+virtual   void                          Dump(void) {};
 
-                                MP4Header( void ) ;
-virtual	                        ~MP4Header(  ) ;
+                                        MP4Header( void ) ;
+virtual                                 ~MP4Header(  ) ;
 // AVI io
-virtual 	uint8_t	       open(const char *name);
-virtual 	uint8_t	       close(void) ;
+virtual 	uint8_t                 open(const char *name);
+virtual 	uint8_t                 close(void) ;
   //__________________________
   //				 Info
   //__________________________
@@ -176,25 +247,25 @@ virtual   uint8_t                       getExtraHeaderData(uint32_t *len, uint8_
 
 virtual 	WAVHeader              *getAudioInfo(uint32_t i )  ;
 virtual 	uint8_t                 getAudioStream(uint32_t i,ADM_audioStream  **audio);
-virtual     uint8_t                     getNbAudioStreams(void);
-virtual        bool                     unreliableBFramePts (void);
+virtual         uint8_t                 getNbAudioStreams(void);
+virtual         bool                    unreliableBFramePts (void);
 // Frames
   //__________________________
   //				 video
   //__________________________
 
-virtual 	uint8_t  setFlag(uint32_t frame,uint32_t flags);
-virtual 	uint32_t getFlags(uint32_t frame,uint32_t *flags);
-virtual 	uint8_t  getFrame(uint32_t framenum,ADMCompressedImage *img);
-virtual     uint8_t getFrameSize (uint32_t frame, uint32_t * size);
-// Multi track
-uint8_t        changeAudioStream(uint32_t newstream);
-uint32_t       getCurrentAudioStreamNumber(void);
-uint8_t        getAudioStreamsInfo(uint32_t *nbStreams, audioInfo **infos);
-virtual   uint64_t                   getTime(uint32_t frameNum);
-virtual   uint64_t                   getVideoDuration(void);
-virtual   bool       getPtsDts(uint32_t frame,uint64_t *pts,uint64_t *dts);
-virtual   bool       setPtsDts(uint32_t frame,uint64_t pts,uint64_t dts);
+virtual 	uint8_t         setFlag(uint32_t frame,uint32_t flags);
+virtual 	uint32_t        getFlags(uint32_t frame,uint32_t *flags);
+virtual 	uint8_t         getFrame(uint32_t framenum,ADMCompressedImage *img);
+virtual         uint8_t         getFrameSize (uint32_t frame, uint32_t * size);
+                // Multi track
+                uint8_t         changeAudioStream(uint32_t newstream);
+                uint32_t        getCurrentAudioStreamNumber(void);
+                uint8_t         getAudioStreamsInfo(uint32_t *nbStreams, audioInfo **infos);
+virtual         uint64_t        getTime(uint32_t frameNum);
+virtual         uint64_t        getVideoDuration(void);
+virtual         bool            getPtsDts(uint32_t frame,uint64_t *pts,uint64_t *dts);
+virtual         bool            setPtsDts(uint32_t frame,uint64_t pts,uint64_t dts);
 
 };
 
