@@ -144,7 +144,7 @@ bool    tsPacket::setPos(uint64_t pos)
 {
     if(!_file->setpos(pos))
     {
-        printf("[tsPacket] Cannot seek to %"PRIx64"\n", pos);
+        printf("[tsPacket] Cannot seek to %" PRIx64"\n", pos);
         return false;
     }
     return true;
@@ -387,7 +387,7 @@ nextPack3:
     zprintf("[TS Demuxer] Code=0x%x pid=0x%x\n",code,pes->pid);
     if((code&0xffffff00)!=0x100)
     {
-        printf("[Ts Demuxer] No PES startcode at 0x%"PRIx64"\n",pkt.startAt);
+        printf("[Ts Demuxer] No PES startcode at 0x%" PRIx64"\n",pkt.startAt);
         printf("0x:%02x %02x %02x %02x\n",pkt.payload[4],pkt.payload[5],pkt.payload[6],pkt.payload[7]);
         goto nextPack3;
     }
@@ -433,7 +433,7 @@ nextPack3:
 /**
     \fn decodePesHeader
 */
-#define fail(x) {printf("[Ts Demuxer]*********"x"*******\n");return false;}
+#define fail(x) {printf("[Ts Demuxer]*********" x"*******\n");return false;}
 bool tsPacket::decodePesHeader(TS_PESpacket *pes)
 {
     uint8_t  *start=pes->payload+6;
@@ -733,10 +733,10 @@ bool    tsPacketLinear::read(uint32_t len, uint8_t *out)
             It is expected that the caller will do -4 to the index to get the start of the 
             startCode
 */
-bool    tsPacketLinear::getInfo(dmxPacketInfo *info)
+bool    tsPacketLinear::getInfo(dmxPacketInfo *info,int startCodeLength)
 {
-#warning FIXME
-    if(pesPacket->offset<4)
+//#warning FIXME
+    if(pesPacket->offset<startCodeLength)
     {
         info->startAt=this->oldStartAt;
         info->offset=oldBufferLen;
@@ -758,9 +758,9 @@ bool    tsPacketLinear::getInfo(dmxPacketInfo *info)
     \brief in some cases (HDRunner/HDCPro), a pes contains multiple video frames. This call consumes pts
             and dts so that the multiple frames do not have the same pts/dts.
 */
-bool     tsPacketLinear::invalidatePtsDts(void)
+bool     tsPacketLinear::invalidatePtsDts(int startCodeLength)
 {
-    if(pesPacket->offset<4)
+    if(pesPacket->offset<startCodeLength)
     {
         oldBufferPts=ADM_NO_PTS;
         oldBufferDts=ADM_NO_PTS;
@@ -780,12 +780,12 @@ bool    tsPacketLinear::seek(uint64_t packetStart, uint32_t offset)
 {
     if(!_file->setpos(packetStart))
     {
-        printf("[tsPacket] Cannot seek to %"PRIx64"\n",packetStart);
+        printf("[tsPacket] Cannot seek to %" PRIx64"\n",packetStart);
         return 0;
     }
     if(!refill())
     {
-        printf("[tsPacketLinear] Seek to %"PRIx64":%"PRIx32" failed\n",packetStart,offset);
+        printf("[tsPacketLinear] Seek to %" PRIx64":%" PRIx32" failed\n",packetStart,offset);
         return false;
     }
     ADM_assert(offset<pesPacket->payloadSize);
