@@ -86,7 +86,7 @@ uint8_t OpenDMLHeader::unpackPacked( void )
 	setpriority(PRIO_PROCESS, 0, ADM_getNiceValue(priorityLevel));
 #endif
 	printf("[Avi] Trying to unpack the stream\n");
-	DIA_workingBase *working=createWorking(QT_TR_NOOP("Unpacking bitstream"));
+	DIA_workingBase *working=createWorking(QT_TRANSLATE_NOOP("opendmldemuxer","Unpacking bitstream"));
 	ADMCompressedImage image;
     image.data=buffer;
 	uint32_t img=0;
@@ -99,7 +99,7 @@ uint8_t OpenDMLHeader::unpackPacked( void )
 		working->update(img,nbFrame);
 		if(!getFrame(img,&image))
         {
-            printf("[Avi] Error could not get frame %"PRIu32"\n",img);
+            printf("[Avi] Error could not get frame %" PRIu32"\n",img);
             goto _abortUnpack;
         }
 		aprintf("--Frame:%lu/%lu, len %lu, nbDuped%u\n",img,nbFrame,image.dataLength,nbDuped);
@@ -214,7 +214,7 @@ _abortUnpack:
 		delete [] newIndex;
 		printf("[Avi] Could not unpack this...\n");
 	}
-	printf("[Avi] Initial # of images : %"PRIu32", now we have %"PRIu32" \n",nbFrame,targetIndex);
+	printf("[Avi] Initial # of images : %" PRIu32", now we have %" PRIu32" \n",nbFrame,targetIndex);
 	nbFrame=targetIndex;
 
 	#ifndef __HAIKU__
