@@ -61,16 +61,16 @@ bool muxerMP4::open(const char *file, ADM_videoStream *s,uint32_t nbAudioTrack,A
 {
     if(!isMpeg4Compatible(s->getFCC()) && !isH264Compatible(s->getFCC()) && !isH265Compatible(s->getFCC()))
     {
-            GUI_Error_HIG("Unsupported","Only MP4Video, H264, and H265 supported for video");
+            GUI_Error_HIG(QT_TRANSLATE_NOOP("mp4muxer","Unsupported"),QT_TRANSLATE_NOOP("mp4muxer","Only MP4Video, H264, and H265 supported for video"));
             return false;
     }
     if(nbAudioTrack)
         for(int i=0;i<nbAudioTrack;i++)
         {
             uint32_t acc=a[i]->getInfo()->encoding;
-            if(acc!=WAV_MP2 && acc!=WAV_MP3 && acc!=WAV_AAC && acc!=WAV_AC3)
+            if(acc!=WAV_MP2 && acc!=WAV_MP3 && acc!=WAV_AAC && acc!=WAV_AC3 && acc!=WAV_EAC3)
             {
-                GUI_Error_HIG("Unsupported","Only AAC, AC3, and mpegaudio supported for audio");
+                GUI_Error_HIG(QT_TRANSLATE_NOOP("mp4muxer","Unsupported"),QT_TRANSLATE_NOOP("mp4muxer","Only AAC, AC3, E-AC3 and mpegaudio supported for audio"));
                 return false;
             }
         }
@@ -93,6 +93,8 @@ bool muxerMP4::open(const char *file, ADM_videoStream *s,uint32_t nbAudioTrack,A
         AVCodecContext *c;
         AVRational myTimeBase;
         c = video_st->codec;
+        AVCodecParameters *par;
+        par = video_st->codecpar;
         rescaleFps(s->getAvgFps1000(),&(c->time_base));
         myTimeBase=video_st->time_base=c->time_base;
         ADM_info("Video stream time base :%d,%d\n",video_st->time_base.num,video_st->time_base.den);
@@ -149,8 +151,8 @@ bool muxerMP4::open(const char *file, ADM_videoStream *s,uint32_t nbAudioTrack,A
 */
 bool muxerMP4::save(void)
 {
-    const char *title=QT_TR_NOOP("Saving mp4");
-    if(muxerConfig.muxerType==MP4_MUXER_PSP) title=QT_TR_NOOP("Saving PSP");
+    const char *title=QT_TRANSLATE_NOOP("mp4muxer","Saving mp4");
+    if(muxerConfig.muxerType==MP4_MUXER_PSP) title=QT_TRANSLATE_NOOP("mp4muxer","Saving PSP");
     return saveLoop(title);
 }
 
