@@ -7,8 +7,8 @@
  ***************************************************************************/
 #include <math.h>
 #include <vector>
-#include <QFileDialog>
 #include <QDialog>
+#include <QFileDialog>
 #include <QTextEdit>
 #include <QLineEdit>
 using std::vector;
@@ -38,7 +38,7 @@ typedef struct
 }idcToken;
 
 static const idcToken listOfIdc[]={
-        {-1,"Auto"},
+        {(unsigned int)-1,"Auto"},
         {10,"1"},
         {11,"1.1"},
         {12,"1.2"},
@@ -85,7 +85,7 @@ static const aspectRatio predefinedARs[]={
 static const char* listOfPresets[] = { "ultrafast", "superfast", "veryfast", "faster", "fast", "medium", "slow", "slower", "veryslow", "placebo" };
 #define NB_PRESET sizeof(listOfPresets)/sizeof(char*)
 
-static const char* listOfTunings[] = { "film", "animation", "grain", "stillimage", "psnr", "ssim" };
+static const char* listOfTunings[] = { "none", "film", "animation", "grain", "stillimage", "psnr", "ssim" };
 #define NB_TUNE sizeof(listOfTunings)/sizeof(char*)
 
 static const char* listOfProfiles[] = { "baseline", "main", "high", "high10", "high422", "high444" };
@@ -97,29 +97,19 @@ static const char* listOfProfiles[] = { "baseline", "main", "high", "high10", "h
 */
 bool x264_ui(x264_encoder *settings)
 {
-        bool success = false;
+    bool success = false;
     x264Dialog dialog(qtLastRegisteredDialog(), settings);
 
-        qtRegisterDialog(&dialog);
+    qtRegisterDialog(&dialog);
 
     if (dialog.exec() == QDialog::Accepted)
     {
             dialog.download();
-            if(settings->general.preset) ADM_dealloc(settings->general.preset);
-            settings->general.preset = NULL;
-            if(settings->general.tuning) ADM_dealloc(settings->general.tuning);
-            settings->general.tuning = NULL;
-            if(settings->general.profile) ADM_dealloc(settings->general.profile);
-            settings->general.profile = NULL;
-            memcpy(settings,&myCopy,sizeof(myCopy));
-            if(myCopy.general.preset) settings->general.preset = ADM_strdup(myCopy.general.preset);
-            if(myCopy.general.tuning) settings->general.tuning = ADM_strdup(myCopy.general.tuning);
-            if(myCopy.general.profile) settings->general.profile = ADM_strdup(myCopy.general.profile);
+            *settings=myCopy;
             success = true;
     }
 
-        qtUnregisterDialog(&dialog);
-
+    qtUnregisterDialog(&dialog);
     return success;
 }
 /**
@@ -143,16 +133,7 @@ x264Dialog::x264Dialog(QWidget *parent, void *param) : QDialog(parent)
         connect(ui.maxCrfSpinBox, SIGNAL(valueChanged(int)), this, SLOT(maxCrfSpinBox_valueChanged(int)));
 #endif
        x264_encoder* settings = (x264_encoder*)param;
-       if(myCopy.general.preset) ADM_dealloc(myCopy.general.preset);
-       myCopy.general.preset = NULL;
-       if(myCopy.general.tuning) ADM_dealloc(myCopy.general.tuning);
-       myCopy.general.tuning = NULL;
-       if(myCopy.general.profile) ADM_dealloc(myCopy.general.profile);
-       myCopy.general.profile = NULL;
-       memcpy(&myCopy,settings,sizeof(myCopy));
-       if(settings->general.preset) myCopy.general.preset = ADM_strdup(settings->general.preset);
-       if(settings->general.tuning) myCopy.general.tuning = ADM_strdup(settings->general.tuning);
-       if(settings->general.profile) myCopy.general.profile = ADM_strdup(settings->general.profile);
+       myCopy=*settings;
 
 #define ENCODING(x)  myCopy.general.params.x       
         lastBitrate =   ENCODING(bitrate);
@@ -190,7 +171,10 @@ x264Dialog::x264Dialog(QWidget *parent, void *param) : QDialog(parent)
         tunings->clear();
         for(int i=0;i<NB_TUNE;i++)
         {
-            tunings->addItem(QString(listOfTunings[i]));
+            const char* _tn=listOfTunings[i];
+            if(!strcmp(_tn,"none"))
+                _tn=QT_TRANSLATE_NOOP("x264","none");
+            tunings->addItem(QString(_tn));
         }
 
         QComboBox* profiles=ui.profileComboBox;
@@ -222,7 +206,7 @@ bool x264Dialog::updatePresetList(void)
     {
         combo->addItem(list[i].c_str());
     }
-    combo->addItem(QString("Custom"));
+    combo->addItem(QString(QT_TRANSLATE_NOOP("x264","Custom")));
     return true;
 }
 
@@ -252,18 +236,21 @@ bool x264Dialog::toogleAdvancedConfiguration(bool advancedEnabled)
 #define DISABLE(x) ui.x->setEnabled(false);
 #define MK_MENU(x,y) ui.x->setCurrentIndex(myCopy.y)
 #define MK_RADIOBUTTON(x) ui.x->setChecked(true);
-#define MK_COMBOBOX_STR(x,y,list,count) \
-  { \
-    QComboBox *combobox=ui.x; \
-    for(int i=0;i<count;i++) \
-    { \
-      const char *p=list[i]; \
-      if(myCopy.y && !strcmp(myCopy.y, p)) \
-      { \
-        combobox->setCurrentIndex(i); \
-      } \
-    } \
-  }
+#define MK_COMBOBOX_STR(x,y,list,count) updateComboBox(ui.x,myCopy.y,count,list)
+/**
+
+*/
+static void updateComboBox(QComboBox *combo,const std::string &mine,int count,const char **list)
+{
+    for(int i=0;i<count;i++) 
+    { 
+      const char *p=list[i]; 
+      if(mine.size() && !strcmp(mine.c_str(), p)) 
+      { 
+        combo->setCurrentIndex(i); 
+      } 
+    } 
+}
 bool x264Dialog::upload(void)
 {
           toogleAdvancedConfiguration(myCopy.useAdvancedConfiguration);
@@ -369,9 +356,9 @@ bool x264Dialog::upload(void)
           }
 
           // preset
-          MK_COMBOBOX_STR(presetComboBox, general.preset, listOfPresets, NB_PRESET);
-          MK_COMBOBOX_STR(profileComboBox, general.profile, listOfProfiles, NB_PROFILE);
-          MK_COMBOBOX_STR(tuningComboBox, general.tuning, listOfTunings, NB_TUNE);
+          MK_COMBOBOX_STR(presetComboBox, general.preset.c_str(), listOfPresets, NB_PRESET);
+          MK_COMBOBOX_STR(profileComboBox, general.profile.c_str(), listOfProfiles, NB_PROFILE);
+          MK_COMBOBOX_STR(tuningComboBox, general.tuning.c_str(), listOfTunings, NB_TUNE);
 
           // udate idc
           QComboBox *idc=ui.idcLevelComboBox;
@@ -472,14 +459,17 @@ bool x264Dialog::upload(void)
 #define MK_UINT(x,y)        myCopy.y=ui.x->value()
 #define MK_MENU(x,y)        myCopy.y=ui.x->currentIndex()
 #define MK_RADIOBUTTON(x,y)   myCopy.y=ui.x->setChecked(true);
-#define MK_COMBOBOX_STR(x,y,list,count) \
-  { \
-    QComboBox* combo=ui.x; \
-    int idx=combo->currentIndex(); \
-    ADM_assert(idx<count); \
-    if(myCopy.y) ADM_dealloc(myCopy.y); \
-    myCopy.y = ADM_strdup(list[idx]); \
-  }
+#define MK_COMBOBOX_STR(x,y,list,count) x_readComboBox(ui.x,myCopy.y,count,list)
+
+static void x_readComboBox(QComboBox *combo, std::string &inout,int count,const char **list)
+{
+    int idx=combo->currentIndex(); 
+    ADM_assert(idx<count);    
+    inout = std::string(list[idx]); 
+}
+
+
+
 
 bool x264Dialog::download(void)
 {
@@ -627,27 +617,27 @@ void x264Dialog::encodingModeComboBox_currentIndexChanged(int index)
         switch (index)
         {
                 case 0:
-                        ui.targetRateControlLabel1->setText(tr("Target Bitrate:"));
-                        ui.targetRateControlLabel2->setText(tr("kbit/s"));
+                        ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x264","Target Bitrate:"));
+                        ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x264","kbit/s"));
                         ui.targetRateControlSpinBox->setValue(lastBitrate);
                         break;
                 case 1: // Constant Quality - 1 pass
-                        ui.quantiserLabel2->setText(tr("Quantiser:"));
+                        ui.quantiserLabel2->setText(QT_TRANSLATE_NOOP("x264","Quantiser:"));
                         enableQp = true;
                         break;
                 case 2: // Average Quantiser - 1 pass
-                        ui.quantiserLabel2->setText(tr("Quality:"));
+                        ui.quantiserLabel2->setText(QT_TRANSLATE_NOOP("x264","Quality:"));
                         enableQp = true;
                         enableMaxCrf = true;
                         break;
                 case 3: // Video Size - 2 pass
-                        ui.targetRateControlLabel1->setText(tr("Target Video Size:"));
-                        ui.targetRateControlLabel2->setText(tr("MB"));
+                        ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x264","Target Video Size:"));
+                        ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x264","MB"));
                         ui.targetRateControlSpinBox->setValue(lastVideoSize);
                         break;
                 case 4: // Average Bitrate - 2 pass
-                        ui.targetRateControlLabel1->setText(tr("Average Bitrate:"));
-                        ui.targetRateControlLabel2->setText(tr("kbit/s"));
+                        ui.targetRateControlLabel1->setText(QT_TRANSLATE_NOOP("x264","Average Bitrate:"));
+                        ui.targetRateControlLabel2->setText(QT_TRANSLATE_NOOP("x264","kbit/s"));
                         ui.targetRateControlSpinBox->setValue(lastBitrate);
                         break;
         }
@@ -714,7 +704,8 @@ void x264Dialog::mbTreeCheckBox_toggled(bool checked)
 {
         if (checked && !ui.aqVarianceCheckBox->isChecked())
         {
-                if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?").toUtf8().constData()))
+                QString st=QT_TRANSLATE_NOOP("x264","Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Variance Adaptive Quantisation will automatically be enabled.\n\nDo you wish to continue?");
+                if (GUI_Question(st.toUtf8().constData()))
                         ui.aqVarianceCheckBox->setChecked(true);
                 else
                         ui.mbTreeCheckBox->setChecked(false);
@@ -725,7 +716,8 @@ void x264Dialog::aqVarianceCheckBox_toggled(bool checked)
 {
         if (!checked && ui.mbTreeCheckBox->isChecked())
         {
-                if (GUI_Question(tr("Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?").toUtf8().constData()))
+                 QString st=QT_TRANSLATE_NOOP("x264","Macroblock-Tree optimisation requires Variance Adaptive Quantisation to be enabled.  Macroblock-Tree optimisation will automatically be disabled.\n\nDo you wish to continue?");
+                if (GUI_Question(st.toUtf8().constData()))
                         ui.mbTreeCheckBox->setChecked(false);
                 else
                         ui.aqVarianceCheckBox->setChecked(true);
@@ -765,7 +757,7 @@ void x264Dialog::configurationComboBox_currentIndexChanged(int index)
     ADM_info("Loading preset %s\n",t);
     if(false==x264_encoder_jdeserialize(t,x264_encoder_param,&myCopy))
     {
-        GUI_Error_HIG("Error","Cannot load preset");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x264","Error"),QT_TRANSLATE_NOOP("x264","Cannot load preset"));
         ADM_error("Cannot read from %s\n",t);
     }else       
     {
@@ -780,7 +772,7 @@ void x264Dialog::configurationComboBox_currentIndexChanged(int index)
 static char *getProfileName(void)
 {
   QDialog dialog;
-  dialog.setWindowTitle(QString::fromUtf8("Save Profile"));
+  dialog.setWindowTitle(QString::fromUtf8(QT_TRANSLATE_NOOP("x264","Save Profile")));
   QDialogButtonBox *buttonBox = new QDialogButtonBox();  
   QVBoxLayout *vboxLayout = new QVBoxLayout();
   buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -791,7 +783,7 @@ static char *getProfileName(void)
   QLineEdit *text=new QLineEdit;
 //  text->setAcceptRichText(false);
 
-  text->setText("my profile");
+  text->setText(QT_TRANSLATE_NOOP("x264","my profile"));
   text->selectAll();
 
   vboxLayout->addWidget(text);
@@ -825,7 +817,7 @@ void x264Dialog::saveAsButton_pressed(void)
 
   if(ADM_fileExist(fullpath.c_str()))
   {
-        if(false==GUI_Confirmation_HIG("Overwrite","Replace the following preset ?:",out))
+        if(false==GUI_Confirmation_HIG(QT_TRANSLATE_NOOP("x264","Overwrite"),QT_TRANSLATE_NOOP("x264","Replace the following preset ?:"),out))
         {
             ADM_dealloc(out);
             return;
@@ -834,7 +826,7 @@ void x264Dialog::saveAsButton_pressed(void)
   ADM_dealloc(out);
   if(false==x264_encoder_jserialize(fullpath.c_str(),&myCopy))
   {
-        GUI_Error_HIG("Error","Cannot save preset");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x264","Error"),QT_TRANSLATE_NOOP("x264","Cannot save preset"));
         ADM_error("Cannot write to %s\n",out);
   }
   updatePresetList();
@@ -848,13 +840,13 @@ void x264Dialog::deleteButton_pressed(void)
     int m=ui.configurationComboBox->count();
     if(n==m-1) // custom
     {
-        GUI_Error_HIG("Error","Cannot delete custom profile");
+        GUI_Error_HIG(QT_TRANSLATE_NOOP("x264","Error"),QT_TRANSLATE_NOOP("x264","Cannot delete custom profile"));
         return;
     }
   QString preset=ui.configurationComboBox->itemText(n);
-  QString msg=QString("Do you really want to delete the ")+preset+
-            QString(" profile ?.\nIf it is a system profile it will be recreated next time.");
-  if(true==GUI_Confirmation_HIG("Delete preset","Delete",msg.toUtf8().constData()))
+  QString msg=QString(QT_TRANSLATE_NOOP("x264","Do you really want to delete the "))+preset+
+            QString(QT_TRANSLATE_NOOP("x264"," profile ?.\nIf it is a system profile it will be recreated next time."));
+  if(true==GUI_Confirmation_HIG(QT_TRANSLATE_NOOP("x264","Delete preset"),QT_TRANSLATE_NOOP("x264","Delete"),msg.toUtf8().constData()))
   {
     std::string rootPath;
     ADM_pluginGetPath("x264",pluginVersion,rootPath);
