@@ -17,7 +17,7 @@ class flyASharp : public ADM_flyDialogYuv
    uint8_t    upload(void);
    uint8_t    update(void);
                 flyASharp (QDialog *parent,uint32_t width,uint32_t height,ADM_coreVideoFilter *in,
-                                    ADM_QCanvas *canvas, QSlider *slider) : 
+                                    ADM_QCanvas *canvas, ADM_QSlider *slider) :
                     ADM_flyDialogYuv(parent,width, height,in,canvas, slider,RESIZE_AUTO) {};
 };
 
