@@ -4,7 +4,7 @@
 /**
     \class flyChromaShift
 */  
-class flyChromaShift : public FLY_DIALOG_TYPE
+class flyChromaShift : public ADM_flyDialogYuv
 {
   
   public:
@@ -15,9 +15,9 @@ class flyChromaShift : public FLY_DIALOG_TYPE
    uint8_t    download(void);
    uint8_t    upload(void);
    uint8_t    update(void);
-   flyChromaShift (uint32_t width,uint32_t height,ADM_coreVideoFilter *in,
-                                    void *canvas, void *slider) 
-                : FLY_DIALOG_TYPE(width, height,in,canvas, slider,1,RESIZE_AUTO) {};
+   flyChromaShift (QDialog *parent,uint32_t width,uint32_t height,ADM_coreVideoFilter *in,
+                                    ADM_QCanvas *canvas, ADM_QSlider *slider)
+                : ADM_flyDialogYuv(parent,width, height,in,canvas, slider,RESIZE_AUTO) {};
 };
 #endif
 //EOF
