@@ -37,12 +37,13 @@ Ui_cropWindow::Ui_cropWindow(QWidget* parent, crop *param,ADM_coreVideoFilter *i
 
         canvas=new ADM_QCanvas(ui.graphicsView,width,height);
         
-        myCrop=new flyCrop( width, height,in,canvas,ui.horizontalSlider);
+        myCrop=new flyCrop( this,width, height,in,canvas,ui.horizontalSlider);
         myCrop->left=param->left;
         myCrop->right=param->right;
         myCrop->top=param->top;
         myCrop->bottom=param->bottom;
         myCrop->_cookie=&ui;
+        myCrop->addControl(ui.toolboxLayout);
         myCrop->upload();
         myCrop->sliderChanged();
 
@@ -56,6 +57,9 @@ Ui_cropWindow::Ui_cropWindow(QWidget* parent, crop *param,ADM_coreVideoFilter *i
           SPINNER(Top);
           SPINNER(Bottom);
 
+        show();
+        myCrop->adjustCanvasPosition();
+        canvas->parentWidget()->setMinimumSize(30,30); // allow resizing both ways after the dialog has settled
   }
   void Ui_cropWindow::sliderUpdate(int foo)
   {
@@ -104,6 +108,16 @@ void Ui_cropWindow::reset( bool f )
          lock--;
 }
 
+void Ui_cropWindow::resizeEvent(QResizeEvent *event)
+{
+    if(!canvas->height())
+        return;
+    uint32_t graphicsViewWidth = canvas->parentWidget()->width();
+    uint32_t graphicsViewHeight = canvas->parentWidget()->height();
+    myCrop->fitCanvasIntoView(graphicsViewWidth,graphicsViewHeight);
+    myCrop->adjustCanvasPosition();
+}
+
 //************************
 uint8_t flyCrop::upload(void)
 {
