@@ -17,8 +17,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "DIA_flyDialog.h"
 #include "ADM_default.h"
+#include "ADM_coreVideoFilter.h"
 #include "ADM_coreVideoFilterInternal.h"
 #include "DIA_factory.h"
 
@@ -26,6 +26,13 @@
 
 #include "eq2_desc.cpp"
 #include <math.h>
+
+#if defined( ADM_CPU_X86) && !defined(_MSC_VER)
+        #define CAN_DO_INLINE_X86_ASM
+        void affine_1d_MMX (oneSetting *par, ADMImage *srcImage, ADMImage *destImage,ADM_PLANE plane);
+#endif
+
+
 /**
     \class ADMVideoEq2
 */
@@ -34,8 +41,6 @@ class  ADMVideoEq2:public ADM_coreVideoFilterCached
 
   protected:
             eq2             _param;    
-            float           _hue;
-            float           _saturation;
             Eq2Settings     settings;   
             void            update(void);
   public:
@@ -142,7 +147,7 @@ void ADMVideoEq2::setCoupledConf(CONFcouple *couples)
   *fn=nextFrame++;
   image->copyInfo(mysrc);
 
-#ifdef ADM_CPU_X86
+#ifdef CAN_DO_INLINE_X86_ASM
   if(CpuCaps::hasMMX())
   {
         affine_1d_MMX(&(settings.param[0]),mysrc,image,PLANAR_Y);
@@ -219,8 +224,11 @@ void create_lut (oneSetting *par)
   gw = par->w;
   lw = 1.0 - gw;
 
-  if ((g < 0.001) || (g > 1000.0)) {
-    g = 1.0;
+  if (g < 0.001) {
+    g = 0.001;
+  }
+  if (g > 1000.0) {
+    g = 1000.0;
   }
 
   g = 1.0 / g;
@@ -253,7 +261,7 @@ void create_lut (oneSetting *par)
   par->lut_clean = 1;
 }
 
-#ifdef ADM_CPU_X86
+#ifdef CAN_DO_INLINE_X86_ASM
 /**
     \fn affine_1d_MMX
 */  
