@@ -51,6 +51,9 @@
           SPINNER(Hue);
           SPINNER(Saturation);
 
+        show();
+        myCrop->adjustCanvasPosition();
+        canvas->parentWidget()->setMinimumSize(30,30); // allow resizing after the dialog has settled
   }
   void Ui_hueWindow::sliderUpdate(int foo)
   {
@@ -78,6 +81,16 @@ void Ui_hueWindow::valueChanged( int f )
   lock--;
 }
 
+void Ui_hueWindow::resizeEvent(QResizeEvent *event)
+{
+    if(!canvas->height())
+        return;
+    uint32_t graphicsViewWidth = canvas->parentWidget()->width();
+    uint32_t graphicsViewHeight = canvas->parentWidget()->height();
+    myCrop->fitCanvasIntoView(graphicsViewWidth,graphicsViewHeight);
+    myCrop->adjustCanvasPosition();
+}
+
 #define MYSPIN(x) w->horizontalSlider##x
 #define MYCHECK(x) w->checkBox##x
 //************************
