@@ -1,6 +1,5 @@
 #ifndef Q_hue_h
 #define Q_hue_h
-#include "DIA_flyDialog.h"
 #include "ui_hue.h"
 #include "ADM_image.h"
 #include "hue.h"
@@ -27,5 +26,8 @@ public slots:
 private slots:
 	void sliderUpdate(int foo);
 	void valueChanged(int foo);
+
+private:
+        void resizeEvent(QResizeEvent *event);
 };
 #endif	// Q_hue_h
